@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2000, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -33,7 +33,6 @@ import java.text.NumberFormat;
 import java.text.ParseException;
 import java.util.Map;
 
-import sun.reflect.misc.ReflectUtil;
 import sun.swing.SwingUtilities2;
 
 /**
@@ -313,7 +312,7 @@ public class NumberFormatter extends InternationalFormatter {
      */
     boolean isNavigatable(int index) {
         if (!super.isNavigatable(index)) {
-            // Don't skip the decimal, it causes wierd behavior
+            // Don't skip the decimal, it causes weird behavior
             return getBufferedChar(index) == getDecimalSeparator();
         }
         return true;
@@ -350,7 +349,7 @@ public class NumberFormatter extends InternationalFormatter {
     }
 
     /**
-     * Overriden to toggle the value if the positive/minus sign
+     * Overridden to toggle the value if the positive/minus sign
      * is inserted.
      */
     void replace(DocumentFilter.FilterBypass fb, int offset, int length,
@@ -437,12 +436,9 @@ public class NumberFormatter extends InternationalFormatter {
                         valueClass = value.getClass();
                     }
                     try {
-                        ReflectUtil.checkPackageAccess(valueClass);
-                        SwingUtilities2.checkAccess(valueClass.getModifiers());
                         Constructor<?> cons = valueClass.getConstructor(
                                               new Class<?>[] { String.class });
                         if (cons != null) {
-                            SwingUtilities2.checkAccess(cons.getModifiers());
                             return cons.newInstance(new Object[]{string});
                         }
                     } catch (Throwable ex) { }
