@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2016, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -38,23 +38,15 @@ import java.util.Objects;
 import jdk.jfr.internal.PlatformRecorder;
 import jdk.jfr.internal.PlatformRecording;
 import jdk.jfr.internal.Type;
-import jdk.jfr.internal.Utils;
-import jdk.jfr.internal.WriteableUserPath;
+import jdk.jfr.internal.util.Utils;
+import jdk.jfr.internal.WriteablePath;
 
 /**
  * Provides means to configure, start, stop and dump recording data to disk.
  * <p>
  * The following example shows how configure, start, stop and dump recording data to disk.
  *
- * <pre>{@literal
- *   Configuration c = Configuration.getConfiguration("default");
- *   Recording r = new Recording(c);
- *   r.start();
- *   System.gc();
- *   Thread.sleep(5000);
- *   r.stop();
- *   r.dump(Files.createTempFile("my-recording", ".jfr"));
- * }</pre>
+ * {@snippet class="Snippets" region="RecordingOverview"}
  *
  * @since 9
  */
@@ -78,7 +70,8 @@ public final class Recording implements Closeable {
 
         @Override
         public EventSettings with(String name, String value) {
-            Objects.requireNonNull(value);
+            Objects.requireNonNull(name, "name");
+            Objects.requireNonNull(value, "value");
             recording.setSetting(identifier + "#" + name, value);
             return this;
         }
@@ -103,13 +96,11 @@ public final class Recording implements Closeable {
      *         example, if the Java Virtual Machine (JVM) lacks Flight Recorder
      *         support, or if the file repository can't be created or accessed)
      *
-     * @throws SecurityException If a security manager is used and
-     *         FlightRecorderPermission "accessFlightRecorder" is not set.
-     *
      * @see jdk.jfr
+     * @since 11
      */
     public Recording(Map<String, String> settings) {
-        Objects.requireNonNull(settings);
+        Objects.requireNonNull(settings, "settings");
         Map<String, String> sanitized = Utils.sanitizeNullFreeStringMap(settings);
         PlatformRecorder r = FlightRecorder.getFlightRecorder().getInternal();
         synchronized (r) {
@@ -130,12 +121,9 @@ public final class Recording implements Closeable {
      * @throws IllegalStateException if Flight Recorder can't be created (for
      *         example, if the Java Virtual Machine (JVM) lacks Flight Recorder
      *         support, or if the file repository can't be created or accessed)
-     *
-     * @throws SecurityException If a security manager is used and
-     *         FlightRecorderPermission "accessFlightRecorder" is not set.
      */
     public Recording() {
-        this(new HashMap<String, String>());
+        this(Map.of());
      }
 
     /**
@@ -143,9 +131,9 @@ public final class Recording implements Closeable {
      * <p>
      * The following example shows how create a recording that uses a predefined configuration.
      *
-     * <pre>{@literal
+     * {@snippet :
      * Recording r = new Recording(Configuration.getConfiguration("default"));
-     * }</pre>
+     * }
      *
      * The newly created recording is in the {@link RecordingState#NEW} state. To
      * start the recording, invoke the {@link Recording#start()} method.
@@ -157,13 +145,10 @@ public final class Recording implements Closeable {
      *         example, if the Java Virtual Machine (JVM) lacks Flight Recorder
      *         support, or if the file repository can't be created or accessed)
      *
-     * @throws SecurityException if a security manager is used and
-     *         FlightRecorderPermission "accessFlightRecorder" is not set.
-     *
      * @see Configuration
      */
     public Recording(Configuration configuration) {
-        this(configuration.getSettings());
+        this(Objects.requireNonNull(configuration, "configuration").getSettings());
     }
 
     /**
@@ -195,7 +180,7 @@ public final class Recording implements Closeable {
      * @throws IllegalStateException if the recording is not it the {@code NEW} state
      */
     public void scheduleStart(Duration delay) {
-        Objects.requireNonNull(delay);
+        Objects.requireNonNull(delay, "delay");
         internal.scheduleStart(delay);
     }
 
@@ -214,10 +199,6 @@ public final class Recording implements Closeable {
      *
      * @throws IllegalStateException if the recording is not started or is already stopped
      *
-     * @throws SecurityException if a security manager exists and the caller
-     *         doesn't have {@code FilePermission} to write to the destination
-     *         path
-     *
      * @see #setDestination(Path)
      *
      */
@@ -307,26 +288,26 @@ public final class Recording implements Closeable {
      * <p>
      * The following example shows how to set event settings for a recording.
      *
-     * <pre>{@literal
+     * {@snippet :
      *     Map<String, String> settings = new HashMap<>();
      *     settings.putAll(EventSettings.enabled("jdk.CPUSample").withPeriod(Duration.ofSeconds(2)).toMap());
      *     settings.putAll(EventSettings.enabled(MyEvent.class).withThreshold(Duration.ofSeconds(2)).withoutStackTrace().toMap());
      *     settings.put("jdk.ExecutionSample#period", "10 ms");
      *     recording.setSettings(settings);
-     * }</pre>
+     * }
      *
      * The following example shows how to merge settings.
      *
-     * <pre>{@literal
+     * {@snippet :
      *     Map<String, String> settings = recording.getSettings();
      *     settings.putAll(additionalSettings);
      *     recording.setSettings(settings);
-     * }</pre>
+     * }
      *
      * @param settings the settings to set, not {@code null}
      */
     public void setSettings(Map<String, String> settings) {
-        Objects.requireNonNull(settings);
+        Objects.requireNonNull(settings, "settings");
         Map<String, String> sanitized = Utils.sanitizeNullFreeStringMap(settings);
         internal.setSettings(sanitized);
     }
@@ -355,7 +336,7 @@ public final class Recording implements Closeable {
 
     /**
      * Returns a clone of this recording, with a new recording ID and name.
-     *
+     * <p>
      * Clones are useful for dumping data without stopping the recording. After
      * a clone is created, the amount of data to copy is constrained
      * with the {@link #setMaxAge(Duration)} method and the {@link #setMaxSize(long)}method.
@@ -371,21 +352,23 @@ public final class Recording implements Closeable {
     /**
      * Writes recording data to a file.
      * <p>
-     * Recording must be started, but not necessarily stopped.
+     * For a dump to succeed, the recording must either be 1) running, or 2) stopped
+     * and to disk. If the recording is in any other state, an
+     * {@link IOException} is thrown.
      *
      * @param destination the location where recording data is written, not
      *        {@code null}
      *
-     * @throws IOException if the recording can't be copied to the specified
-     *         location
+     * @throws IOException if recording data can't be copied to the specified
+     *         location, for example, if the recording is closed or the
+     *         destination path is not writable
      *
-     * @throws SecurityException if a security manager exists and the caller doesn't
-     *         have {@code FilePermission} to write to the destination path
+     * @see #getState()
+     * @see #isToDisk()
      */
     public void dump(Path destination) throws IOException {
-        Objects.requireNonNull(destination);
-        internal.dump(new WriteableUserPath(destination));
-
+        Objects.requireNonNull(destination, "destination");
+        internal.dump(new WriteablePath(destination));
     }
 
     /**
@@ -424,25 +407,6 @@ public final class Recording implements Closeable {
         internal.setMaxSize(maxSize);
     }
 
-        /**
-         * Determines how often events are made available for streaming.
-         *
-         * @param interval the interval at which events are made available for streaming.
-         *
-         * @throws IllegalArgumentException if {@code interval} is negative
-         *
-         * @throws IllegalStateException if the recording is in the {@code CLOSED} state
-         *
-         * @since 14
-         */
-        /*package private*/ void setFlushInterval(Duration interval) {
-            Objects.nonNull(interval);
-            if (interval.isNegative()) {
-                throw new IllegalArgumentException("Stream interval can't be negative");
-            }
-            internal.setFlushInterval(interval);
-        }
-
     /**
      * Returns how often events are made available for streaming purposes.
      *
@@ -494,14 +458,10 @@ public final class Recording implements Closeable {
      * @throws IllegalStateException if recording is in the {@code STOPPED} or
      *         {@code CLOSED} state.
      *
-     * @throws SecurityException if a security manager exists and the caller
-     *         doesn't have {@code FilePermission} to read, write, and delete the
-     *         {@code destination} file
-     *
      * @throws IOException if the path is not writable
      */
     public void setDestination(Path destination) throws IOException {
-        internal.setDestination(destination != null ? new WriteableUserPath(destination) : null);
+        internal.setDestination(destination != null ? new WriteablePath(destination) : null);
     }
 
     /**
@@ -511,11 +471,11 @@ public final class Recording implements Closeable {
      * @return the destination file, or {@code null} if not set.
      */
     public Path getDestination() {
-        WriteableUserPath usp = internal.getDestination();
-        if (usp == null) {
+        WriteablePath wp = internal.getDestination();
+        if (wp == null) {
             return null;
         } else {
-            return usp.getPotentiallyMaliciousOriginal();
+            return wp.getPath();
         }
     }
 
@@ -536,7 +496,7 @@ public final class Recording implements Closeable {
      * @throws IllegalStateException if the recording is in {@code CLOSED} state
      */
     public void setName(String name) {
-        Objects.requireNonNull(name);
+        Objects.requireNonNull(name, "name");
         internal.setName(name);
     }
 
@@ -577,6 +537,9 @@ public final class Recording implements Closeable {
      * Creates a data stream for a specified interval.
      * <p>
      * The stream may contain some data outside the specified range.
+     * <p>
+     * If the recording is not to disk, a stream can't be created
+     * and {@code null} is returned.
      *
      * @param start the start time for the stream, or {@code null} to get data from
      *        start time of the recording
@@ -585,12 +548,14 @@ public final class Recording implements Closeable {
      *        present time.
      *
      * @return an input stream, or {@code null} if no data is available in the
-     *         interval.
+     *         interval, or the recording was not recorded to disk
      *
      * @throws IllegalArgumentException if {@code end} happens before
      *         {@code start}
      *
      * @throws IOException if a stream can't be opened
+     *
+     * @see #setToDisk(boolean)
      */
     public InputStream getStream(Instant start, Instant end) throws IOException {
         if (start != null && end != null && end.isBefore(start)) {
@@ -641,7 +606,7 @@ public final class Recording implements Closeable {
      * @see EventType
      */
     public EventSettings enable(String name) {
-        Objects.requireNonNull(name);
+        Objects.requireNonNull(name, "name");
         RecordingSettings rs = new RecordingSettings(this, name);
         rs.with("enabled", "true");
         return rs;
@@ -662,7 +627,7 @@ public final class Recording implements Closeable {
      *
      */
     public EventSettings disable(String name) {
-        Objects.requireNonNull(name);
+        Objects.requireNonNull(name, "name");
         RecordingSettings rs = new RecordingSettings(this, name);
         rs.with("enabled", "false");
         return rs;
@@ -679,7 +644,7 @@ public final class Recording implements Closeable {
      * @return an event setting for further configuration, not {@code null}
      */
     public EventSettings enable(Class<? extends Event> eventClass) {
-        Objects.requireNonNull(eventClass);
+        Objects.requireNonNull(eventClass, "eventClass");
         RecordingSettings rs = new RecordingSettings(this, eventClass);
         rs.with("enabled", "true");
         return rs;
@@ -697,7 +662,7 @@ public final class Recording implements Closeable {
      *
      */
     public EventSettings disable(Class<? extends Event> eventClass) {
-        Objects.requireNonNull(eventClass);
+        Objects.requireNonNull(eventClass, "eventClass");
         RecordingSettings rs = new RecordingSettings(this, eventClass);
         rs.with("enabled", "false");
         return rs;
@@ -709,8 +674,8 @@ public final class Recording implements Closeable {
     }
 
     private void setSetting(String id, String value) {
-        Objects.requireNonNull(id);
-        Objects.requireNonNull(value);
+        Objects.requireNonNull(id, "id");
+        Objects.requireNonNull(value, "value");
         internal.setSetting(id, value);
     }
 
