@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,252 +67,10 @@ public class CurrencyNames_cy extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
-            { "AED", "AED" },
-            { "AFA", "AFA" },
-            { "AFN", "AFN" },
-            { "ALL", "ALL" },
-            { "AMD", "AMD" },
-            { "ANG", "ANG" },
-            { "AOA", "AOA" },
-            { "AOK", "AOK" },
-            { "AON", "AON" },
-            { "AOR", "AOR" },
-            { "ARA", "ARA" },
-            { "ARL", "ARL" },
-            { "ARM", "ARM" },
-            { "ARP", "ARP" },
-            { "ARS", "ARS" },
-            { "ATS", "ATS" },
-            { "AWG", "AWG" },
-            { "AZM", "AZM" },
-            { "AZN", "AZN" },
-            { "BAM", "BAM" },
-            { "BBD", "BBD" },
-            { "BDT", "BDT" },
-            { "BEC", "BEC" },
-            { "BEF", "BEF" },
-            { "BEL", "BEL" },
-            { "BGM", "BGM" },
-            { "BGN", "BGN" },
-            { "BGO", "BGO" },
-            { "BHD", "BHD" },
-            { "BIF", "BIF" },
-            { "BMD", "BMD" },
-            { "BND", "BND" },
-            { "BOB", "BOB" },
-            { "BOL", "BOL" },
-            { "BOP", "BOP" },
-            { "BOV", "BOV" },
-            { "BRB", "BRB" },
-            { "BRC", "BRC" },
-            { "BRE", "BRE" },
-            { "BRN", "BRN" },
-            { "BRR", "BRR" },
-            { "BRZ", "BRZ" },
-            { "BSD", "BSD" },
-            { "BTN", "BTN" },
-            { "BUK", "BUK" },
-            { "BWP", "BWP" },
-            { "BYN", "BYN" },
-            { "BYR", "BYR" },
-            { "BZD", "BZD" },
-            { "CDF", "CDF" },
-            { "CHE", "CHE" },
-            { "CHF", "CHF" },
-            { "CHW", "CHW" },
-            { "CLE", "CLE" },
-            { "CLF", "CLF" },
-            { "CLP", "CLP" },
-            { "CNH", "CNH" },
-            { "COP", "COP" },
-            { "COU", "COU" },
-            { "CRC", "CRC" },
-            { "CSD", "CSD" },
-            { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CVE", "CVE" },
-            { "CYP", "CYP" },
-            { "CZK", "CZK" },
-            { "DDM", "DDM" },
-            { "DEM", "DEM" },
-            { "DJF", "DJF" },
-            { "DKK", "DKK" },
-            { "DOP", "DOP" },
-            { "DZD", "DZD" },
-            { "ECS", "ECS" },
-            { "EGP", "EGP" },
-            { "ERN", "ERN" },
-            { "ESP", "ESP" },
-            { "ETB", "ETB" },
-            { "FIM", "FIM" },
-            { "FJD", "FJD" },
-            { "FKP", "FKP" },
-            { "FRF", "FRF" },
-            { "GEK", "GEK" },
-            { "GEL", "GEL" },
-            { "GHC", "GHC" },
-            { "GHS", "GHS" },
-            { "GIP", "GIP" },
-            { "GMD", "GMD" },
-            { "GNF", "GNF" },
-            { "GNS", "GNS" },
-            { "GQE", "GQE" },
-            { "GRD", "GRD" },
-            { "GTQ", "GTQ" },
-            { "GWE", "GWE" },
-            { "GWP", "GWP" },
-            { "GYD", "GYD" },
-            { "HNL", "HNL" },
-            { "HRD", "HRD" },
-            { "HRK", "HRK" },
-            { "HTG", "HTG" },
-            { "HUF", "HUF" },
-            { "IDR", "IDR" },
-            { "IEP", "IEP" },
-            { "ILP", "ILP" },
-            { "IQD", "IQD" },
-            { "IRR", "IRR" },
-            { "ISK", "ISK" },
-            { "ITL", "ITL" },
-            { "JMD", "JMD" },
-            { "JOD", "JOD" },
-            { "KES", "KES" },
-            { "KGS", "KGS" },
-            { "KHR", "KHR" },
-            { "KMF", "KMF" },
-            { "KPW", "KPW" },
-            { "KRH", "KRH" },
-            { "KRO", "KRO" },
             { "KRW", "KRW" },
-            { "KWD", "KWD" },
-            { "KYD", "KYD" },
-            { "KZT", "KZT" },
-            { "LAK", "LAK" },
-            { "LBP", "LBP" },
-            { "LKR", "LKR" },
-            { "LRD", "LRD" },
-            { "LSL", "LSL" },
-            { "LTL", "LTL" },
-            { "LTT", "LTT" },
-            { "LUC", "LUC" },
-            { "LUF", "LUF" },
-            { "LUL", "LUL" },
-            { "LVL", "LVL" },
-            { "LVR", "LVR" },
-            { "LYD", "LYD" },
-            { "MAD", "MAD" },
-            { "MAF", "MAF" },
-            { "MCF", "MCF" },
-            { "MDL", "MDL" },
-            { "MGA", "MGA" },
-            { "MGF", "MGF" },
-            { "MKD", "MKD" },
-            { "MKN", "MKN" },
-            { "MLF", "MLF" },
-            { "MMK", "MMK" },
-            { "MNT", "MNT" },
-            { "MOP", "MOP" },
-            { "MRO", "MRO" },
-            { "MRU", "MRU" },
-            { "MTL", "MTL" },
-            { "MTP", "MTP" },
-            { "MUR", "MUR" },
-            { "MVR", "MVR" },
-            { "MWK", "MWK" },
-            { "MXP", "MXP" },
-            { "MXV", "MXV" },
-            { "MYR", "MYR" },
-            { "MZE", "MZE" },
-            { "MZM", "MZM" },
-            { "MZN", "MZN" },
-            { "NAD", "NAD" },
-            { "NGN", "NGN" },
-            { "NIC", "NIC" },
-            { "NIO", "NIO" },
-            { "NLG", "NLG" },
-            { "NOK", "NOK" },
-            { "NPR", "NPR" },
-            { "OMR", "OMR" },
-            { "PAB", "PAB" },
-            { "PEI", "PEI" },
-            { "PEN", "PEN" },
-            { "PES", "PES" },
-            { "PGK", "PGK" },
             { "PHP", "PHP" },
-            { "PKR", "PKR" },
-            { "PLN", "PLN" },
-            { "PTE", "PTE" },
-            { "PYG", "PYG" },
-            { "QAR", "QAR" },
-            { "RHD", "RHD" },
-            { "RON", "RON" },
-            { "RSD", "RSD" },
-            { "RUB", "RUB" },
-            { "RWF", "RWF" },
-            { "SAR", "SAR" },
-            { "SBD", "SBD" },
-            { "SCR", "SCR" },
-            { "SDD", "SDD" },
-            { "SDG", "SDG" },
-            { "SDP", "SDP" },
-            { "SEK", "SEK" },
-            { "SGD", "SGD" },
-            { "SHP", "SHP" },
-            { "SIT", "SIT" },
-            { "SLL", "SLL" },
-            { "SOS", "SOS" },
-            { "SRD", "SRD" },
-            { "SRG", "SRG" },
-            { "SSP", "SSP" },
-            { "STD", "STD" },
-            { "STN", "STN" },
-            { "SVC", "SVC" },
-            { "SYP", "SYP" },
-            { "SZL", "SZL" },
             { "THB", "\u0e3f" },
-            { "TJR", "TJR" },
-            { "TJS", "TJS" },
-            { "TMM", "TMM" },
-            { "TMT", "TMT" },
-            { "TND", "TND" },
-            { "TOP", "TOP" },
-            { "TPE", "TPE" },
-            { "TRL", "TRL" },
-            { "TRY", "TRY" },
-            { "TTD", "TTD" },
-            { "TZS", "TZS" },
-            { "UAH", "UAH" },
-            { "UGS", "UGS" },
-            { "UGX", "UGX" },
-            { "USN", "USN" },
-            { "USS", "USS" },
-            { "UYI", "UYI" },
-            { "UYP", "UYP" },
-            { "UYU", "UYU" },
-            { "UZS", "UZS" },
-            { "VEB", "VEB" },
-            { "VEF", "VEF" },
-            { "VES", "VES" },
-            { "VNN", "VNN" },
-            { "VUV", "VUV" },
-            { "WST", "WST" },
-            { "XEU", "XEU" },
             { "XXX", "XXX" },
-            { "YDD", "YDD" },
-            { "YER", "YER" },
-            { "YUD", "YUD" },
-            { "YUM", "YUM" },
-            { "YUN", "YUN" },
-            { "YUR", "YUR" },
-            { "ZAL", "ZAL" },
-            { "ZAR", "ZAR" },
-            { "ZMK", "ZMK" },
-            { "ZMW", "ZMW" },
-            { "ZRN", "ZRN" },
-            { "ZRZ", "ZRZ" },
-            { "ZWD", "ZWD" },
-            { "ZWL", "ZWL" },
-            { "ZWR", "ZWR" },
             { "aed", "Dirham Yr Emiradau Arabaidd Unedig" },
             { "afa", "Afghani Afghanistan (1927\u20132002)" },
             { "afn", "Afghani Afghanistan" },
@@ -467,7 +221,7 @@ public class CurrencyNames_cy extends OpenListResourceBundle {
             { "mlf", "Ffranc Mali" },
             { "mmk", "Kyat Myanmar" },
             { "mnt", "Tugrik Mongolia" },
-            { "mop", "Pataca Macau" },
+            { "mop", "pataca Macau" },
             { "mro", "Ouguiya Mauritania (1973\u20132017)" },
             { "mru", "Ouguiya Mauritania" },
             { "mur", "Rwp\u00ee Mauritius" },
@@ -514,7 +268,8 @@ public class CurrencyNames_cy extends OpenListResourceBundle {
             { "sek", "Krona Sweden" },
             { "sgd", "Doler Singapore" },
             { "shp", "Punt St Helena" },
-            { "sll", "Leone Sierra Leone" },
+            { "sle", "Leone Sierra Leone" },
+            { "sll", "Leone Sierra Leone (1964\u20142022)" },
             { "sos", "Swllt Somalia" },
             { "srd", "Doler Surinam" },
             { "srg", "Guilder Surinam" },
