@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,6 +67,8 @@ public class CurrencyNames_ks extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "JPY", "\u00a5" },
+            { "USD", "$" },
             { "adp", "\u0627\u0620\u0691\u0648\u0631\u064e\u0646 \u067e\u06cc\u0633\u0650\u0679\u0627" },
             { "aed", "\u0645\u064f\u062a\u062d\u062f\u06c1 \u0639\u0631\u0628 \u0627\u0650\u0645\u0627\u0631\u0627\u062a \u062f\u0650\u0631\u06c1\u0645" },
             { "afn", "\u0627\u0641\u063a\u0627\u0646 \u0627\u0641\u063a\u0672\u0646\u06cc" },
@@ -101,7 +99,7 @@ public class CurrencyNames_ks extends OpenListResourceBundle {
             { "brb", "\u0628\u0631\u0627\u0632\u06cc\u0656\u0644\u06cc\u0646 \u06a9\u0631\u0648\u0632\u0650\u0631\u0648 \u0646\u0648\u0648\u0648" },
             { "brc", "\u0628\u0631\u0627\u0632\u06cc\u0656\u0644\u06cc\u0646 \u06a9\u0631\u0648\u0632\u06cc\u0691\u0648" },
             { "bre", "\u0628\u0631\u0627\u0632\u06cc\u0656\u0644\u06cc\u0646 \u06a9\u0631\u0648\u0632\u0650\u0631\u0648" },
-            { "brl", "\u0628\u0631\u0627\u0632\u06cc\u0656\u0644\u06cc\u0646 \u0631\u0650\u06cc\u064e\u0644" },
+            { "brl", "\u0628\u0631\u0627\u0632\u06cc\u0656\u0644\u06cc \u0631\u0650\u06cc\u064e\u0644" },
             { "brn", "\u0628\u0631\u0627\u0632\u06cc\u0656\u0644\u06cc\u0646 \u06a9\u0631\u0648\u0632\u06cc\u0691\u0648 \u0646\u0648\u0648\u0648" },
             { "brr", "\u0628\u0631\u0627\u0632\u06cc\u0656\u0644\u06cc\u0646 \u06a9\u0631\u0648\u0632\u06cc\u0631\u0648" },
             { "bsd", "\u0628\u06c1\u0627\u0645\u0650\u06cc\u064e\u0646 \u0688\u0627\u0644\u0631" },
@@ -119,7 +117,7 @@ public class CurrencyNames_ks extends OpenListResourceBundle {
             { "chw", "\u0648\u0650\u0631 \u0641\u0631\u06cc\u06a9" },
             { "clf", "\u0686\u0650\u0644\u0650\u0646 \u06cc\u0648\u0657\u0646\u0650\u0691\u06cc\u062f\u06cc\u0656\u0632 \u0691\u0650 \u0641\u0648\u0645\u06cc\u0679\u0648" },
             { "clp", "\u0686\u0650\u0644\u0650\u0646 \u067e\u0650\u0633\u0648" },
-            { "cny", "\u0686\u06cc\u0646\u06cc\u0656\u0632 \u06cc\u064e\u0646 \u0631\u0650\u0646\u0645\u0650\u0646\u0628\u06cc" },
+            { "cny", "\u0686\u06cc\u0656\u0646\u06cc \u06cc\u064f\u0648\u0627\u0646" },
             { "cop", "\u06a9\u0648\u0644\u064e\u0645\u0628\u0650\u06cc\u0646 \u067e\u0650\u0633\u0648" },
             { "cou", "\u0650\u0656\u06cc\u0648\u0657\u0646\u0650\u0691\u06cc\u0691 \u0691\u0650 \u0648\u06cc\u0644\u0648\u0631 \u0631\u0650\u06cc\u0644" },
             { "crc", "\u06a9\u0648\u0633\u0679\u0627 \u0631\u0650\u06a9\u064e\u0646 \u06a9\u0648\u0644\u064e\u0646" },
@@ -143,7 +141,7 @@ public class CurrencyNames_ks extends OpenListResourceBundle {
             { "fjd", "\u0641\u0650\u062c\u06cc\u0646 \u0688\u0627\u0644\u0631" },
             { "fkp", "\u0641\u06cc\u06a9\u0644\u06cc\u0646\u0691\u0650\u0633 \u0622\u06cc\u0644\u06cc\u0646\u0691 \u067e\u0648\u0646\u0691" },
             { "frf", "\u0641\u0631\u0627\u0646\u0633\u0650\u0633\u06cc \u0641\u0631\u06cc\u06a9" },
-            { "gbp", "\u0628\u0631\u0637\u0672\u0646\u0648\u06cc \u067e\u0627\u0648\u0646\u0691 \u0633\u0679\u0654\u0631\u0644\u0650\u0646\u06af" },
+            { "gbp", "\u0628\u0631\u0637\u0672\u0646\u0648\u06cc \u067e\u0648\u0657\u0646\u0688" },
             { "gek", "\u062c\u0627\u0631\u062c\u0650\u06cc\u064e\u0646 \u06a9\u06cc\u0648\u0657\u067e\u064e\u0646 \u0644\u064e\u0631\u0650\u0679" },
             { "gel", "\u062c\u0627\u0631\u062c\u0650\u06cc\u064e\u0646 \u0644\u0627\u0631\u06cc" },
             { "ghc", "\u06af\u064e\u0646\u06cc\u06cc\u064e\u0646 \u0633\u0620\u0691\u06cc(\u06f1\u06f9\u06f7\u06f9\u2013\u06f2\u0660\u0660\u06f7)" },
@@ -167,8 +165,8 @@ public class CurrencyNames_ks extends OpenListResourceBundle {
             { "idr", "\u0627\u0650\u0646\u0691\u0648\u0646\u06cc\u0634\u06cc\u0627\u06c1\u064f\u06a9 \u0631\u064f\u067e\u0650\u06cc\u0627\u06c1" },
             { "iep", "\u0627\u064e\u06cc\u0631\u0644\u06cc\u0646\u0691\u064f\u06a9 \u067e\u0627\u0648\u0646\u0691" },
             { "ilp", "\u0627\u0650\u0632\u0631\u0672\u06cc\u0650\u0644\u06cc \u067e\u0627\u0648\u0646\u0691" },
-            { "ils", "\u0627\u0650\u0632\u0631\u0672\u06cc\u0650\u0644\u06cc \u0646\u0654\u0648\u06cd \u0634\u0620\u0642\u0655\u0644" },
-            { "inr", "\u06c1\u0650\u0646\u062f\u064f\u0633\u062a\u0672\u0646\u06cd \u0631\u06c4\u067e\u064e\u06d2" },
+            { "ils", "\u0627\u0650\u0632\u0631\u0672\u06cc\u0650\u0644\u06cc \u0646\u0654\u0648\u0620 \u0634\u0620\u0642\u0655\u0644" },
+            { "inr", "\u06c1\u0650\u0646\u062f\u064f\u0633\u062a\u0672\u0646\u0620 \u0631\u06c4\u067e\u064e\u06d2" },
             { "iqd", "\u0627\u06cc\u0656\u0631\u0627\u0642\u064f\u06a9 \u062f\u06cc\u0656\u0646\u0627\u0631" },
             { "irr", "\u0627\u06cc\u0656\u0631\u0627\u0646\u064f\u06a9 \u0631\u0650\u06cc\u0627\u0644" },
             { "isk", "\u0627\u064e\u06cc\u0633\u0644\u06cc\u0646\u0691\u064f\u06a9 \u06a9\u0631\u0648\u0646\u0627" },
@@ -236,7 +234,7 @@ public class CurrencyNames_ks extends OpenListResourceBundle {
             { "pes", "\u067e\u0654\u0631\u06cc\u0648\u0657\u0648\u0650\u06cc\u064e\u0646 \u0633\u0648\u0644 (\u06f1\u06f8\u06f6\u06f3\u2013\u06f1\u06f9\u06f6\u06f5)" },
             { "pgk", "\u0646\u06cc\u0648\u0657 \u067e\u06cc\u067e\u064f\u0639\u0627 \u06af\u0650\u0646\u0650\u06cc\u064e\u0646 \u06a9\u06cc\u0656\u0646\u0627" },
             { "php", "\u067e\u06be\u0650\u0644\u0650\u067e\u0627\u06cc\u0650\u0654\u0646 \u067e\u0620\u0633\u0648" },
-            { "pkr", "\u067e\u0627\u06a9\u0650\u0633\u062a\u0672\u0646\u06cd \u0631\u06c4\u067e\u064e\u06d2" },
+            { "pkr", "\u067e\u0627\u06a9\u0650\u0633\u062a\u0672\u0646\u0620 \u0631\u06c4\u067e\u064e\u06d2" },
             { "pln", "\u067e\u0648\u0644\u0650\u0634 \u0632\u0644\u0648\u0679\u06cc" },
             { "plz", "\u067e\u0648\u0644\u0650\u0634 \u0632\u0644\u0648\u0679\u06cc(\u06f1\u06f9\u06f5\u0660\u2013\u06f1\u06f9\u06f9\u06f5)" },
             { "pte", "\u067e\u0648\u0631\u062a\u064f\u06af\u06cc\u0656\u0632 \u0627\u0620\u0633\u06a9\u06cc\u0648\u0657\u0691\u0648" },
@@ -246,7 +244,7 @@ public class CurrencyNames_ks extends OpenListResourceBundle {
             { "rol", "\u0627\u0648\u0644\u0691 \u0631\u0648\u0645\u0627\u0646\u0650\u06cc\u064e\u0646 \u0644\u0620\u06cc\u0648\u0657" },
             { "ron", "\u0631\u0648\u0645\u0627\u0646\u0650\u06cc\u064e\u0646 \u0644\u0620\u06cc\u0648\u0657" },
             { "rsd", "\u0633\u0654\u0631\u0628\u0650\u06cc\u064e\u0646 \u062f\u06cc\u0656\u0646\u0627\u0631" },
-            { "rub", "\u0631\u0654\u0634\u06cc\u064e\u0646 \u0631\u064e\u0628\u0655\u0644" },
+            { "rub", "\u0631\u0648\u0657\u0633\u06cc \u0631\u064e\u0628\u0655\u0644" },
             { "rur", "\u0631\u0654\u0634\u06cc\u064e\u0646 \u0631\u064e\u0628\u0655\u0644(\u06f1\u06f9\u06f9\u06f1\u2013\u06f1\u06f9\u06f9\u06f8)" },
             { "rwf", "\u0631\u0648\u0627\u0646\u0691\u064e\u0646 \u0641\u0631\u0627\u0646\u06a9" },
             { "sar", "\u0633\u0648\u062f\u06cc\u0656\u06cc\u064f\u06a9 \u0631\u0650\u06cc\u0627\u0644" },
@@ -282,7 +280,7 @@ public class CurrencyNames_ks extends OpenListResourceBundle {
             { "uak", "\u06cc\u0648\u0657\u06a9\u0631\u06cc\u0646\u06cc\u0627\u06c1\u064f\u06a9 \u06a9\u0627\u0631\u0628\u0648\u0648\u064e\u0646\u06cc\u0679\u0633" },
             { "ugs", "\u0627\u064f\u06af\u0627\u062f\u0627\u06c1\u064f\u06a9 \u0634\u0650\u0644\u0650\u0646\u06af(\u06f1\u06f9\u06f6\u06f6\u2013\u06f1\u06f9\u06f8\u06f7)" },
             { "ugx", "\u0627\u064f\u06af\u0627\u062f\u0627\u06c1\u064f\u06a9 \u0634\u0650\u0644\u0650\u0646\u06af" },
-            { "usd", "\u06cc\u0648\u0657 \u0627\u06cc\u0633 \u0688\u0627\u0644\u064e\u0631" },
+            { "usd", "US \u0688\u0627\u0644\u0631" },
             { "usn", "\u06cc\u0648\u0657 \u0627\u06cc\u0633 \u0688\u0627\u0644\u064e\u0631(\u067e\u064e\u06af\u0627\u06c1)" },
             { "uss", "\u06cc\u0648\u0657 \u0627\u06cc\u0633 \u0688\u0627\u0644\u064e\u0631(\u062a\u064e\u0645\u06cc \u062f\u064b\u06c4\u06c1)" },
             { "uyi", "\u0627\u064f\u0631\u06af\u0627\u06cc\u064e\u0646 \u067e\u06cc\u0633\u0648 \u06cc\u0648\u0657\u0646\u0650\u0688\u06cc\u0688\u064e\u0633 \u0627\u0650\u0646\u0688\u06cc\u06a9\u0633\u064e\u0633" },
@@ -313,7 +311,7 @@ public class CurrencyNames_ks extends OpenListResourceBundle {
             { "xpt", "\u067e\u0644\u06cc\u0679\u0650\u0646\u064e\u0645" },
             { "xre", "\u0622\u0631 \u0622\u06d2 \u0627\u06cc\u0646 \u0627\u06cc\u0656 \u0679\u06cc \u0641\u064e\u0646\u0688" },
             { "xts", "\u0679\u06cc\u0633\u0679\u0650\u0646\u06af \u06a9\u064e\u0631\u064e\u0646\u0633\u06cc \u06a9\u0648\u0688" },
-            { "xxx", "\u0627\u064e\u0646\u0632\u0672\u0646\u06cd \u06cc\u0627 \u0646\u0627\u0644\u064e\u06af\u06c1\u0655 \u06c1\u0627\u0631 \u0633\u0650\u06a9\u06c1\u0655" },
+            { "xxx", "\u0646\u0627\u0645\u0648\u0644\u0648\u0657\u0645 \u06a9\u0631\u0646\u0633\u06cc" },
             { "ydd", "\u06cc\u064e\u0645\u0646\u064f\u06a9 \u062f\u06cc\u0656\u0646\u0627\u0631" },
             { "yer", "\u06cc\u064e\u0645\u0646\u064f\u06a9 \u0631\u0650\u06cc\u0627\u0644" },
             { "yud", "\u06cc\u0648\u06af\u0648\u0633\u0644\u0627\u0648\u0650\u06cc\u064e\u0646 \u06c1\u0627\u0691 \u062f\u06cc\u0656\u0646\u0627\u0631" },
