@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -437,6 +437,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "hz", "\u0647\u06cc\u0631\u0648\u0631\u0648" },
             { "ia", "\u0627\u0646\u067c\u0631\u0644\u0646\u06ab\u0648\u0627" },
             { "id", "\u0627\u0646\u0689\u0648\u0646\u06d0\u0632\u064a" },
+            { "ie", "\u0622\u0633\u0627 \u0646\u0627 \u062c\u0628\u0629" },
             { "ig", "\u0627\u06ab\u0628\u0648" },
             { "ii", "\u0633\u06cc\u0686\u06cc\u0627\u0646 \u06cc\u06cc" },
             { "io", "\u0627\u068a\u0648" },
@@ -545,6 +546,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "xh", "\u062e\u0648\u0633\u0627" },
             { "yi", "\u064a\u062f\u064a\u0634" },
             { "yo", "\u06cc\u0648\u0631\u0648\u0628\u0627" },
+            { "za", "\u0698\u0648\u0627\u0646\u06ab" },
             { "zh", "\u0686\u06cc\u0646\u064a" },
             { "zu", "\u0632\u0648\u0644\u0648" },
             { "ace", "\u0627\u0686\u064a\u0646\u064a" },
@@ -572,6 +574,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "bho", "\u0628\u0647\u0648\u062c\u067e\u0648\u0631\u064a" },
             { "bin", "\u0628\u06cc\u0646\u06cc" },
             { "bla", "\u0633\u06a9\u0633\u064a\u06a9\u0627" },
+            { "blo", "\u0627\u0646\u06cd" },
             { "brx", "\u0628\u0648\u062f\u0648" },
             { "bug", "\u0628\u06af\u0646\u064a\u0627\u064a\u064a" },
             { "byn", "\u0628\u0644\u06cc\u0646" },
@@ -646,7 +649,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "kde", "\u0645\u064a\u06a9\u0648\u0646\u0689\u064a" },
             { "kea", "\u06a9\u0627\u0628\u0648\u0648\u0631\u0689\u06cc\u0627\u0646\u0648" },
             { "kfo", "\u06a9\u0648\u0631\u0648" },
-            { "kgp", "kgg" },
+            { "kgp", "\u06a9\u06cc\u0646\u06ab\u0627" },
             { "kha", "\u062e\u0627\u0633\u06d0" },
             { "khq", "\u06a9\u0648\u06cc\u0631\u0627 \u0686\u06cc\u0646\u06cc" },
             { "kkj", "\u06a9\u0627\u06a9\u0648" },
@@ -662,9 +665,11 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "ksh", "\u06a9\u0648\u0644\u0648\u06ab\u0646\u064a\u0627\u064a\u064a" },
             { "kum", "\u06a9\u0648\u0645\u06a9" },
             { "kwk", "Vote kwk" },
+            { "kxv", "\u06a9\u0648\u0648\u0626" },
             { "lad", "\u0644\u0627\u0689\u06cc\u0646\u0648" },
             { "lag", "\u0644\u0646\u06ab\u06cc" },
             { "lez", "\u0644\u06cc\u06ab\u063a\u06cc\u0627\u0646" },
+            { "lij", "\u0644\u06cc\u0646\u06ab\u0648\u0631\u06cc\u0646" },
             { "lil", "lill" },
             { "lkt", "\u0644\u06a9\u0648\u067c\u0627" },
             { "lmo", "\u0644\u0648\u0645\u0628\u0627\u0631\u0689" },
@@ -758,6 +763,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "suk", "\u0633\u06a9\u0648\u0645\u0627" },
             { "swb", "\u06a9\u0648\u0645\u0648\u0631\u064a\u0627\u0646\u064a" },
             { "syr", "\u0633\u0648\u0631\u06cc\u0627\u0646\u064a" },
+            { "szl", "\u0633\u06cc\u0644\u06cc\u0633\u06cc\u0627\u0646" },
             { "tce", "\u062c\u0646\u0648\u0628\u064a \u062a\u0648\u0686\u0648\u0646" },
             { "tem", "\u062a\u06cc\u0645\u0646\u064a" },
             { "teo", "\u062a\u06cc\u0633\u0648" },
@@ -780,12 +786,15 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "umb", "\u0627\u0645\u0628\u0648\u0646\u062f\u0648" },
             { "und", "\u0646\u0627\u0645\u0639\u0644\u0648\u0645\u0647 \u0698\u0628\u0647" },
             { "vai", metaValue_vai },
+            { "vec", "\u0648\u06cc\u0646\u067c\u06cc\u0627\u0646" },
+            { "vmw", "\u0645\u06a9\u0648\u0647" },
             { "vun", "\u0648\u0648\u0646\u062c\u0648" },
             { "wae", "\u0648\u0644\u0633\u06cc\u0631" },
             { "wal", "\u0648\u0644\u0627\u06cc\u067c\u0627" },
             { "war", "\u0648\u0627\u0631\u06cd" },
             { "wuu", "\u0648\u0648 \u0686\u06cc\u0646\u0627\u06cc\u06cc" },
             { "xal", "\u06a9\u0627\u0644\u0645\u06a9" },
+            { "xnr", "\u06a9\u0627\u0646\u06ab\u0631\u0648" },
             { "xog", "\u0633\u0648\u06ab\u0627" },
             { "yav", "\u06cc\u0646\u06ab\u0628\u06cc\u0646" },
             { "ybb", "\u06cc\u0645\u0628\u0627" },
