@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -86,9 +86,9 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
                "\u0905\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u092e\u093e\u0928\u0915 \u0938\u092e\u093e\u0902",
                "AST",
                "\u0905\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u0921\u0947\u0932\u093e\u0907\u091f \u0938\u092e\u093e\u0902",
-               "ADT",
+               "AST",
                "\u0905\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u0938\u092e\u093e\u0902",
-               "AT",
+               "AST",
             };
         final String[] Europe_Central = new String[] {
                "\u0915\u0947\u0902\u0926\u0930\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u092e\u093e\u0928\u0915 \u0938\u092e\u093e\u0902",
@@ -108,11 +108,11 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
             };
         final String[] Europe_Western = new String[] {
                "\u092a\u091a\u094d\u091b\u092e\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u092e\u093e\u0928\u0915 \u0938\u092e\u093e\u0902",
-               "FMT",
+               "WET",
                "\u092a\u091a\u094d\u091b\u092e\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u0917\u0930\u094d\u092e\u093f\u092f\u0947\u0902 \u0926\u093e \u0938\u092e\u093e\u0902",
-               "FMT",
+               "WEST",
                "\u092a\u091a\u094d\u091b\u092e\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u0938\u092e\u093e\u0902",
-               "FMT",
+               "WET",
             };
         final String[] America_Central = new String[] {
                "\u0909\u0924\u094d\u0924\u0930\u0940 \u0905\u092e\u0930\u0940\u0915\u0940 \u092e\u093e\u0928\u0915 \u0915\u0947\u0902\u0926\u0930\u0940 \u0938\u092e\u093e\u0902",
@@ -142,9 +142,9 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
                "\u0909\u0924\u094d\u0924\u0930\u0940 \u0905\u092e\u0930\u0940\u0915\u0940 \u092e\u093e\u0928\u0915 \u092e\u093e\u0909\u0902\u091f\u0947\u0928 \u0938\u092e\u093e\u0902",
                "MST",
                "\u0909\u0924\u094d\u0924\u0930\u0940 \u0905\u092e\u0930\u0940\u0915\u0940 \u0921\u0947\u0932\u093e\u0907\u091f \u092e\u093e\u0909\u0902\u091f\u0947\u0928 \u0938\u092e\u093e\u0902",
-               "MDT",
+               "MST",
                "\u0909\u0924\u094d\u0924\u0930\u0940 \u0905\u092e\u0930\u0940\u0915\u0940 \u092e\u093e\u0909\u0902\u091f\u0947\u0928 \u0938\u092e\u093e\u0902",
-               "MT",
+               "MST",
             };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
@@ -158,26 +158,132 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
             { "GMT", GMT },
             { "Europe/Bucharest", Europe_Eastern },
             { "UTC", ETC_UTC },
+            { "GB",
+                new String[] {
+                    "\u0917\u094d\u0930\u0940\u0928\u0935\u093f\u091a \u092e\u0940\u0928 \u091f\u093e\u0907\u092e",
+                    "GMT",
+                    "\u092c\u094d\u0930\u093f\u091f\u093f\u0936 \u0917\u0930\u094d\u092e\u093f\u092f\u0947\u0902 \u0926\u093e \u0938\u092e\u093e\u0902",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "ART", Europe_Eastern },
+            { "CET", Europe_Central },
             { "CST", America_Central },
             { "ECT", Europe_Central },
+            { "EET", Europe_Eastern },
+            { "EST", America_Eastern },
+            { "IET", America_Eastern },
+            { "MET", Europe_Central },
+            { "MST", America_Mountain },
             { "PNT", America_Mountain },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "UCT",
+                new String[] {
+                    "\u0924\u093e\u0932\u092e\u0947\u0932\u0940 \u0906\u0932\u092e\u0940 \u0938\u092e\u093e\u0902",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "WET", Europe_Western },
+            { "Eire",
+                new String[] {
+                    "\u0917\u094d\u0930\u0940\u0928\u0935\u093f\u091a \u092e\u0940\u0928 \u091f\u093e\u0907\u092e",
+                    "GMT",
+                    "\u0906\u092f\u0930\u093f\u0936 \u092e\u093e\u0928\u0915 \u0938\u092e\u093e\u0902",
+                    "IST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "GMT0", GMT },
+            { "Zulu",
+                new String[] {
+                    "\u0924\u093e\u0932\u092e\u0947\u0932\u0940 \u0906\u0932\u092e\u0940 \u0938\u092e\u093e\u0902",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Libya", Europe_Eastern },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "\u0924\u093e\u0932\u092e\u0947\u0932\u0940 \u0906\u0932\u092e\u0940 \u0938\u092e\u093e\u0902",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Etc/UTC", ETC_UTC },
+            { "GB-Eire",
+                new String[] {
+                    "\u0917\u094d\u0930\u0940\u0928\u0935\u093f\u091a \u092e\u0940\u0928 \u091f\u093e\u0907\u092e",
+                    "GMT",
+                    "\u092c\u094d\u0930\u093f\u091f\u093f\u0936 \u0917\u0930\u094d\u092e\u093f\u092f\u0947\u0902 \u0926\u093e \u0938\u092e\u093e\u0902",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "\u0924\u093e\u0932\u092e\u0947\u0932\u0940 \u0906\u0932\u092e\u0940 \u0938\u092e\u093e\u0902",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Portugal", Europe_Western },
             { "Asia/Gaza", Europe_Eastern },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Universal",
+                new String[] {
+                    "\u0924\u093e\u0932\u092e\u0947\u0932\u0940 \u0906\u0932\u092e\u0940 \u0938\u092e\u093e\u0902",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -197,6 +303,17 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
             { "America/Aruba", Atlantic },
             { "America/Boise", America_Mountain },
             { "America/Thule", Atlantic },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "\u0924\u093e\u0932\u092e\u0947\u0932\u0940 \u0906\u0932\u092e\u0940 \u0938\u092e\u093e\u0902",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
@@ -209,7 +326,16 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
-            { "Europe/Jersey", GMT },
+            { "Europe/Jersey",
+                new String[] {
+                    "\u0917\u094d\u0930\u0940\u0928\u0935\u093f\u091a \u092e\u0940\u0928 \u091f\u093e\u0907\u092e",
+                    "GMT",
+                    "\u092c\u094d\u0930\u093f\u091f\u093f\u0936 \u0917\u0930\u094d\u092e\u093f\u092f\u0947\u0902 \u0926\u093e \u0938\u092e\u093e\u0902",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -242,6 +368,11 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
             { "America/Nassau", America_Eastern },
             { "America/Panama", America_Eastern },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -253,9 +384,11 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
+            { "Mexico/General", America_Central },
             { "Africa/Freetown", GMT },
             { "Africa/Monrovia", GMT },
             { "Africa/Sao_Tome", GMT },
@@ -267,6 +400,7 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Moncton", Atlantic },
@@ -277,14 +411,26 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
             { "America/Tortola", Atlantic },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/Guernsey", GMT },
+            { "Europe/Guernsey",
+                new String[] {
+                    "\u0917\u094d\u0930\u0940\u0928\u0935\u093f\u091a \u092e\u0940\u0928 \u091f\u093e\u0907\u092e",
+                    "GMT",
+                    "\u092c\u094d\u0930\u093f\u091f\u093f\u0936 \u0917\u0930\u094d\u092e\u093f\u092f\u0947\u0902 \u0926\u093e \u0938\u092e\u093e\u0902",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
@@ -292,9 +438,11 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
             { "SystemV/MST7MDT", America_Mountain },
             { "SystemV/PST8PDT", America_Pacific },
             { "America/Anguilla", Atlantic },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Ensenada", America_Pacific },
             { "America/Montreal", America_Eastern },
             { "America/Resolute", America_Central },
             { "America/Shiprock", America_Mountain },
@@ -310,6 +458,7 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
             { "Europe/Mariehamn", Europe_Eastern },
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Africa/Nouakchott", GMT },
             { "America/Chihuahua", America_Central },
             { "America/Glace_Bay", Atlantic },
@@ -325,6 +474,7 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
             { "Europe/Luxembourg", Europe_Central },
             { "Europe/San_Marino", Europe_Central },
             { "Europe/Zaporozhye", Europe_Eastern },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Ouagadougou", GMT },
             { "America/Costa_Rica", America_Central },
             { "America/Grand_Turk", America_Eastern },
@@ -337,7 +487,16 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
-            { "Europe/Isle_of_Man", GMT },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "\u0917\u094d\u0930\u0940\u0928\u0935\u093f\u091a \u092e\u0940\u0928 \u091f\u093e\u0907\u092e",
+                    "GMT",
+                    "\u092c\u094d\u0930\u093f\u091f\u093f\u0936 \u0917\u0930\u094d\u092e\u093f\u092f\u0947\u0902 \u0926\u093e \u0938\u092e\u093e\u0902",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "America/El_Salvador", America_Central },
             { "America/Fort_Nelson", America_Mountain },
@@ -349,11 +508,13 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
             { "America/Thunder_Bay", America_Eastern },
             { "America/Yellowknife", America_Mountain },
             { "Arctic/Longyearbyen", Europe_Central },
+            { "Canada/Saskatchewan", America_Central },
             { "America/Blanc-Sablon", Atlantic },
             { "America/Danmarkshavn", GMT },
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
+            { "America/Santa_Isabel", America_Pacific },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -370,10 +531,12 @@ public class TimeZoneNames_doi extends TimeZoneNamesBundle {
             { "America/Indiana/Tell_City", America_Central },
             { "America/Indiana/Vincennes", America_Eastern },
             { "America/Indiana/Petersburg", America_Eastern },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Etc/Unknown", "\u0905\u0928\u091c\u093e\u0902\u0924\u093e \u0936\u0948\u0939\u094d\u200c\u0930" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "America/North_Dakota/New_Salem", America_Central },
         };
         return data;
