@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -76,11 +76,11 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "Alaska-Schtandardziit",
-               "",
+               "AKST",
                "Alaska-Summerziit",
-               "",
+               "AKDT",
                "Alaska-Ziit",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "Amazonas-Schtandardziit",
@@ -116,11 +116,11 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Zentralafrikanischi Ziit",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "Oschtafrikanischi Ziit",
@@ -188,16 +188,30 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "CAT", Africa_Central },
+            { "CET", Europe_Central },
             { "CST", America_Central },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "EET", Europe_Eastern },
+            { "MET", Europe_Central },
+            { "WET", Europe_Western },
+            { "W-SU", Moscow },
+            { "Egypt", Europe_Eastern },
+            { "Libya", Europe_Eastern },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
+            { "Portugal", Europe_Western },
             { "Asia/Gaza", Europe_Eastern },
+            { "US/Alaska", Alaska },
             { "Asia/Kabul", Afghanistan },
+            { "US/Central", America_Central },
             { "Africa/Juba", Africa_Central },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
+            { "Brazil/Acre", Acre },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
@@ -212,6 +226,7 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "Europe/Sofia", Europe_Eastern },
             { "Europe/Vaduz", Europe_Central },
             { "SystemV/CST6", America_Central },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
             { "Africa/Douala", Africa_Western },
@@ -248,11 +263,15 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "America/Manaus", Amazon },
             { "America/Merida", America_Central },
             { "America/Regina", America_Central },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Canada/Central", America_Central },
             { "Europe/Andorra", Europe_Central },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
+            { "Mexico/General", America_Central },
             { "Africa/Blantyre", Africa_Central },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Gaborone", Africa_Central },
@@ -260,6 +279,7 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "Africa/Kinshasa", Africa_Western },
             { "Africa/Ndjamena", Africa_Western },
             { "Africa/Windhoek", Africa_Central },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Ojinaga", America_Central },
             { "America/Yakutat", Alaska },
@@ -272,6 +292,7 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "Europe/Chisinau", Europe_Eastern },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/YST9YDT", Alaska },
@@ -302,10 +323,12 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "Europe/San_Marino", Europe_Central },
             { "Europe/Simferopol", Moscow },
             { "Europe/Zaporozhye", Europe_Eastern },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "America/Costa_Rica", America_Central },
             { "America/Metlakatla", Alaska },
+            { "America/Porto_Acre", Acre },
             { "America/Rio_Branco", Acre },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Europe/Kaliningrad", Europe_Eastern },
@@ -316,6 +339,7 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "America/Rainy_River", America_Central },
             { "America/Tegucigalpa", America_Central },
             { "Arctic/Longyearbyen", Europe_Central },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
@@ -376,7 +400,6 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "timezone.excity.Atlantic/Faeroe", "F\u00e4r\u00f6er" },
             { "timezone.excity.Europe/Brussels", "Br\u00fcssel" },
             { "timezone.excity.Europe/Chisinau", "Kischinau" },
-            { "timezone.excity.Europe/Uzhgorod", "Uschgorod" },
             { "timezone.excity.Indian/Maldives", "Maledive" },
             { "timezone.excity.Africa/Mogadishu", "Mogadischu" },
             { "timezone.excity.Asia/Krasnoyarsk", "Krasnojarsk" },
@@ -389,7 +412,6 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Vostok", "Woschtok" },
             { "timezone.excity.Europe/Copenhagen", "Kopehage" },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
-            { "timezone.excity.Europe/Zaporozhye", "Saporischja" },
             { "timezone.excity.Africa/Addis_Ababa", "Addis Abeba" },
             { "timezone.excity.Africa/Ouagadougou", "Wagadugu" },
             { "timezone.excity.Asia/Yekaterinburg", "Jekaterinburg" },
