@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -178,14 +178,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Casey = new String[] {
-               "casey-i id\u0151",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Chile = new String[] {
                "chilei t\u00e9li id\u0151",
                "",
@@ -220,11 +212,11 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             };
         final String[] India = new String[] {
                "indiai t\u00e9li id\u0151",
+               "IST",
                "",
+               "IST",
                "",
-               "",
-               "",
-               "",
+               "IST",
             };
         final String[] Japan = new String[] {
                "jap\u00e1n t\u00e9li id\u0151",
@@ -300,11 +292,11 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "alaszkai z\u00f3naid\u0151",
-               "",
+               "AKST",
                "alaszkai ny\u00e1ri id\u0151",
-               "",
+               "AKDT",
                "alaszkai id\u0151",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "amaz\u00f3niai t\u00e9li id\u0151",
@@ -324,11 +316,11 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "azori t\u00e9li id\u0151",
-               "HMT",
+               "",
                "azori ny\u00e1ri id\u0151",
-               "HMT",
+               "",
                "azori id\u0151z\u00f3na",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "but\u00e1ni id\u0151",
@@ -614,9 +606,9 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "atlanti-\u00f3ce\u00e1ni z\u00f3naid\u0151",
                "AST",
                "atlanti-\u00f3ce\u00e1ni ny\u00e1ri id\u0151",
-               "ADT",
+               "AST",
                "atlanti-\u00f3ce\u00e1ni id\u0151",
-               "AT",
+               "AST",
             };
         final String[] Brasilia = new String[] {
                "braz\u00edliai t\u00e9li id\u0151",
@@ -850,6 +842,14 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Kazakhstan = new String[] {
+               "kazahszt\u00e1ni id\u0151",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Seychelles = new String[] {
                "seychelle-szigeteki id\u0151",
                "",
@@ -988,11 +988,11 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "k\u00f6z\u00e9p-afrikai t\u00e9li id\u0151",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "kelet-afrikai t\u00e9li id\u0151",
@@ -1126,9 +1126,9 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "hegyvid\u00e9ki z\u00f3naid\u0151",
                "MST",
                "hegyvid\u00e9ki ny\u00e1ri id\u0151",
-               "MDT",
+               "MST",
                "hegyvid\u00e9ki id\u0151",
-               "MT",
+               "MST",
             };
         final String[] Marshall_Islands = new String[] {
                "marshall-szigeteki id\u0151",
@@ -1138,14 +1138,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "\u00e9szaknyugat-mexik\u00f3i z\u00f3naid\u0151",
-               "",
-               "\u00e9szaknyugat-mexik\u00f3i ny\u00e1ri id\u0151",
-               "",
-               "\u00e9szaknyugat-mexik\u00f3i id\u0151",
-               "",
-            };
         final String[] Papua_New_Guinea = new String[] {
                "p\u00e1pua \u00faj-guineai id\u0151",
                "",
@@ -1172,27 +1164,11 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             };
         final String[] Australia_Western = new String[] {
                "nyugat-ausztr\u00e1liai t\u00e9li id\u0151",
-               "",
+               "AWST",
                "nyugat-ausztr\u00e1liai ny\u00e1ri id\u0151",
-               "",
+               "AWDT",
                "nyugat-ausztr\u00e1liai id\u0151",
-               "",
-            };
-        final String[] Greenland_Eastern = new String[] {
-               "kelet-gr\u00f6nlandi t\u00e9li id\u0151",
-               "",
-               "kelet-gr\u00f6nlandi ny\u00e1ri id\u0151",
-               "",
-               "kelet-gr\u00f6nlandi id\u0151z\u00f3na",
-               "",
-            };
-        final String[] Greenland_Western = new String[] {
-               "nyugat-gr\u00f6nlandi t\u00e9li id\u0151",
-               "",
-               "nyugat-gr\u00f6nlandi ny\u00e1ri id\u0151",
-               "",
-               "nyugat-gr\u00f6nlandi id\u0151z\u00f3na",
-               "",
+               "AWT",
             };
         final String[] Indonesia_Central = new String[] {
                "k\u00f6z\u00e9p-indon\u00e9ziai id\u0151",
@@ -1218,22 +1194,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "",
                "WIB",
             };
-        final String[] Kazakhstan_Eastern = new String[] {
-               "kelet-kazahszt\u00e1ni id\u0151",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Kazakhstan_Western = new String[] {
-               "nyugat-kazahszt\u00e1ni id\u0151",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Australia_CentralWestern = new String[] {
                "k\u00f6z\u00e9p-nyugat-ausztr\u00e1liai t\u00e9li id\u0151",
                "",
@@ -1261,54 +1221,178 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
             { "UTC", ETC_UTC },
+            { "GB",
+                new String[] {
+                    "greenwichi k\u00f6z\u00e9pid\u0151, t\u00e9li id\u0151",
+                    "GMT",
+                    "brit ny\u00e1ri id\u0151",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "NZ", New_Zealand },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "BET", Brasilia },
             { "BST", Bangladesh },
             { "CAT", Africa_Central },
+            { "CET", Europe_Central },
             { "CNT", Newfoundland },
             { "CST", America_Central },
             { "CTT", China },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "EET", Europe_Eastern },
+            { "EST", America_Eastern },
+            { "HST", Hawaii_Aleutian },
+            { "IET", America_Eastern },
+            { "IST", India },
             { "JST", Japan },
+            { "MET", Europe_Central },
             { "MIT", Apia },
+            { "MST", America_Mountain },
             { "NET", Armenia },
             { "NST", New_Zealand },
             { "PLT", Pakistan },
             { "PNT", America_Mountain },
+            { "PRC", China },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "ROK", Korea },
             { "SST", Solomon },
+            { "UCT",
+                new String[] {
+                    "koordin\u00e1lt vil\u00e1gid\u0151",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "VST", Indochina },
+            { "WET", Europe_Western },
+            { "Cuba", Cuba },
+            { "Eire",
+                new String[] {
+                    "greenwichi k\u00f6z\u00e9pid\u0151, t\u00e9li id\u0151",
+                    "GMT",
+                    "\u00edr ny\u00e1ri id\u0151",
+                    "IST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "GMT0", GMT },
+            { "Iran", Iran },
+            { "W-SU", Moscow },
+            { "Zulu",
+                new String[] {
+                    "koordin\u00e1lt vil\u00e1gid\u0151",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Japan", Japan },
+            { "Libya", Europe_Eastern },
+            { "Israel", Israel },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "koordin\u00e1lt vil\u00e1gid\u0151",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Etc/UTC", ETC_UTC },
+            { "GB-Eire",
+                new String[] {
+                    "greenwichi k\u00f6z\u00e9pid\u0151, t\u00e9li id\u0151",
+                    "GMT",
+                    "brit ny\u00e1ri id\u0151",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
+            { "NZ-CHAT", Chatham },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "koordin\u00e1lt vil\u00e1gid\u0151",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Hongkong", Hong_Kong },
+            { "Portugal", Europe_Western },
+            { "US/Samoa", Samoa },
             { "Asia/Aden", Arabian },
             { "Asia/Baku", Azerbaijan },
             { "Asia/Dili", East_Timor },
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
-            { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Aqtau", Kazakhstan_Western },
+            { "Asia/Oral", Kazakhstan },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Kwajalein", Marshall_Islands },
+            { "Singapore", Singapore },
+            { "US/Alaska", Alaska },
+            { "US/Hawaii", Hawaii_Aleutian },
+            { "Universal",
+                new String[] {
+                    "koordin\u00e1lt vil\u00e1gid\u0151",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Asia/Aqtau", Kazakhstan },
             { "Asia/Chita", Yakutsk },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Dubai", Gulf },
             { "Asia/Kabul", Afghanistan },
+            { "Asia/Macao", China },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
-            { "Asia/Almaty", Kazakhstan_Eastern },
+            { "Asia/Almaty", Kazakhstan },
             { "Asia/Anadyr", Anadyr },
-            { "Asia/Aqtobe", Kazakhstan_Western },
-            { "Asia/Atyrau", Kazakhstan_Western },
+            { "Asia/Aqtobe", Kazakhstan },
+            { "Asia/Atyrau", Kazakhstan },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Brunei", Brunei },
             { "Asia/Harbin", China },
@@ -1320,12 +1404,21 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Asia/Saigon", Indochina },
             { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
+            { "Asia/Thimbu", Bhutan },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/Acre", Acre },
+            { "Brazil/East", Brasilia },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Indian/Mahe", Seychelles },
-            { "Pacific/Yap", Truk },
+            { "Pacific/Yap", Papua_New_Guinea },
+            { "US/Aleutian", Hawaii_Aleutian },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -1333,6 +1426,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
             { "America/Adak", Hawaii_Aleutian },
+            { "America/Atka", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
             { "Asia/Baghdad", Arabian },
@@ -1343,7 +1437,8 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Asia/Irkutsk", Irkutsk },
             { "Asia/Jakarta", Indonesia_Western },
             { "Asia/Karachi", Pakistan },
-            { "Asia/Kuching", Malaysia },
+            { "Asia/Kolkata", India },
+            { "Asia/Kuching", Brunei },
             { "Asia/Magadan", Magadan },
             { "Asia/Nicosia", Europe_Eastern },
             { "Asia/Rangoon", Myanmar },
@@ -1351,6 +1446,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Asia/Thimphu", Bhutan },
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
+            { "Canada/Yukon", Yukon },
             { "Europe/Malta", Europe_Central },
             { "Europe/Minsk", Moscow },
             { "Europe/Sofia", Europe_Eastern },
@@ -1368,6 +1464,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "SystemV/MST7", America_Mountain },
             { "SystemV/PST8", Pitcairn },
             { "SystemV/YST9", Gambier },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bamako", GMT },
             { "Africa/Bangui", Africa_Western },
@@ -1395,10 +1492,25 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
+            { "Asia/Qostanay", Kazakhstan },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
+            { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/LHI", Lord_Howe },
+            { "Australia/NSW", Australia_Eastern },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "koordin\u00e1lt vil\u00e1gid\u0151",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
@@ -1411,7 +1523,16 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
-            { "Europe/Jersey", GMT },
+            { "Europe/Jersey",
+                new String[] {
+                    "greenwichi k\u00f6z\u00e9pid\u0151, t\u00e9li id\u0151",
+                    "GMT",
+                    "brit ny\u00e1ri id\u0151",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -1436,9 +1557,11 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Indian/Chagos", Indian_Ocean },
             { "Indian/Comoro", Africa_Eastern },
+            { "Pacific/Chuuk", Papua_New_Guinea },
             { "Pacific/Efate", Vanuatu },
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
+            { "Pacific/Samoa", Samoa },
             { "SystemV/HST10", Hawaii_Aleutian },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
@@ -1465,15 +1588,24 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
+            { "Asia/Chungking", China },
             { "Asia/Hong_Kong", Hong_Kong },
             { "Asia/Kamchatka", Kamchatka },
+            { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
             { "Asia/Pyongyang", Korea },
-            { "Asia/Qyzylorda", Kazakhstan_Western },
+            { "Asia/Qyzylorda", Kazakhstan },
             { "Asia/Samarkand", Uzbekistan },
             { "Asia/Singapore", Singapore },
             { "Asia/Vientiane", Indochina },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -1485,21 +1617,25 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "Indian/Reunion", Reunion },
+            { "Mexico/BajaSur", Mexico_Pacific },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kanton", Phoenix_Islands },
             { "Pacific/Kosrae", Kosrae },
             { "Pacific/Majuro", Marshall_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
-            { "Pacific/Ponape", Ponape },
+            { "Pacific/Ponape", Solomon },
             { "Pacific/Saipan", Chamorro },
             { "Pacific/Tahiti", Tahiti },
-            { "Pacific/Tarawa", Gilbert_Islands },
-            { "Pacific/Wallis", Wallis },
+            { "Pacific/Tarawa", Marshall_Islands },
+            { "Pacific/Wallis", Gilbert_Islands },
             { "Africa/Blantyre", Africa_Central },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Freetown", GMT },
@@ -1518,10 +1654,10 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Godthab", Greenland_Western },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
@@ -1535,25 +1671,41 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Yakutat", Alaska },
             { "Asia/Choibalsan", Mongolia },
             { "Asia/Phnom_Penh", Indochina },
+            { "Asia/Ulan_Bator", Mongolia },
             { "Atlantic/Azores", Azores },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/North", Australia_Central },
             { "Australia/Perth", Australia_Western },
+            { "Australia/South", Australia_Central },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/Guernsey", GMT },
+            { "Europe/Guernsey",
+                new String[] {
+                    "greenwichi k\u00f6z\u00e9pid\u0151, t\u00e9li id\u0151",
+                    "GMT",
+                    "brit ny\u00e1ri id\u0151",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
-            { "Indian/Maldives", Maldives },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
             { "Pacific/Fakaofo", Tokelau },
             { "Pacific/Gambier", Gambier },
             { "Pacific/Norfolk", Norfolk },
+            { "Pacific/Pohnpei", Solomon },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
@@ -1564,10 +1716,12 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Africa/Mogadishu", Africa_Eastern },
             { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
             { "America/Eirunepe", Acre },
+            { "America/Ensenada", America_Pacific },
             { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
@@ -1578,10 +1732,11 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
+            { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1593,6 +1748,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
@@ -1603,6 +1759,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
             { "Pacific/Johnston", Hawaii_Aleutian },
@@ -1630,6 +1787,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Antarctica/Vostok", Vostok },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Chile/Continental", Chile },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
             { "Europe/Luxembourg", Europe_Central },
@@ -1643,6 +1801,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Pacific/Pago_Pago", Samoa },
             { "Pacific/Rarotonga", Cook },
             { "Pacific/Tongatapu", Tonga },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "Africa/Ouagadougou", GMT },
@@ -1657,19 +1816,34 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Montevideo", Uruguay },
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
+            { "America/Porto_Acre", Acre },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
             { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
             { "Australia/Adelaide", Australia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
-            { "Europe/Isle_of_Man", GMT },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "greenwichi k\u00f6z\u00e9pid\u0151, t\u00e9li id\u0151",
+                    "GMT",
+                    "brit ny\u00e1ri id\u0151",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "Pacific/Kiritimati", Line_Islands },
             { "Africa/Johannesburg", Africa_Southern },
@@ -1687,6 +1861,8 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Pacific/Guadalcanal", Solomon },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
@@ -1697,10 +1873,11 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Santa_Isabel", Mexico_Northwest },
-            { "America/Scoresbysund", Greenland_Eastern },
+            { "America/Santa_Isabel", America_Pacific },
             { "Antarctica/Macquarie", Australia_Eastern },
-            { "Pacific/Port_Moresby", Papua_New_Guinea },
+            { "Australia/Queensland", Australia_Eastern },
+            { "Australia/Yancowinna", Australia_Central },
+            { "Pacific/Port_Moresby", DumontDUrville },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1715,9 +1892,12 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
             { "Atlantic/South_Georgia", South_Georgia },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -1740,6 +1920,8 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Seoul", "Sz\u00f6ul" },
             { "timezone.excity.Asia/Tokyo", "Toki\u00f3" },
             { "timezone.excity.Asia/Tomsk", "Tomszk" },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
@@ -1758,6 +1940,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Etc/Unknown", "Ismeretlen v\u00e1ros" },
             { "timezone.excity.Europe/Kiev", "Kijev" },
             { "timezone.excity.Europe/Rome", "R\u00f3ma" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Africa/Cairo", "Kair\u00f3" },
             { "timezone.excity.Africa/Tunis", "Tunisz" },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
@@ -1779,7 +1962,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Fiji", "Fidzsi" },
             { "timezone.excity.Pacific/Truk", "Truk" },
             { "timezone.excity.Pacific/Wake", "Wake-sziget" },
-            { "timezone.excity.Africa/Asmera", "Asmera" },
+            { "timezone.excity.Africa/Asmera", "Aszmara" },
             { "timezone.excity.Africa/Malabo", "Malab\u00f3" },
             { "timezone.excity.America/Belem", "Bel\u00e9m" },
             { "timezone.excity.Asia/Ashgabat", "Asgabat" },
@@ -1806,6 +1989,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Zagreb", "Z\u00e1gr\u00e1b" },
             { "timezone.excity.Europe/Zurich", "Z\u00fcrich" },
             { "timezone.excity.Indian/Comoro", "Komor\u00f3" },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Algiers", "Alg\u00edr" },
@@ -1834,7 +2018,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/El_Aaiun", "El-Aj\u00fan" },
             { "timezone.excity.Africa/Khartoum", "Kart\u00fam" },
             { "timezone.excity.America/Cordoba", "C\u00f3rdoba" },
-            { "timezone.excity.Asia/Choibalsan", "Csojbalszan" },
             { "timezone.excity.Atlantic/Azores", "Azori-szigetek" },
             { "timezone.excity.Atlantic/Canary", "Kan\u00e1ri-szigetek" },
             { "timezone.excity.Atlantic/Faeroe", "Fer\u00f6er" },
@@ -1843,7 +2026,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
             { "timezone.excity.Europe/Istanbul", "Isztanbul" },
             { "timezone.excity.Europe/Sarajevo", "Szarajev\u00f3" },
-            { "timezone.excity.Europe/Uzhgorod", "Ungv\u00e1r" },
             { "timezone.excity.Indian/Maldives", "Mald\u00edv-szigetek" },
             { "timezone.excity.Pacific/Chatham", "Chatham-szigetek" },
             { "timezone.excity.Pacific/Gambier", "Gambier-szigetek" },
@@ -1854,7 +2036,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Novosibirsk", "Novoszibirszk" },
             { "timezone.excity.Asia/Ulaanbaatar", "Ul\u00e1nb\u00e1tor" },
             { "timezone.excity.Asia/Vladivostok", "Vlagyivosztok" },
-            { "timezone.excity.Australia/Currie", "Currie" },
             { "timezone.excity.Europe/Amsterdam", "Amszterdam" },
             { "timezone.excity.Europe/Astrakhan", "Asztrah\u00e1n" },
             { "timezone.excity.Europe/Bucharest", "Bukarest" },
@@ -1872,7 +2053,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Copenhagen", "Koppenh\u00e1ga" },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
             { "timezone.excity.Europe/Simferopol", "Szimferopol" },
-            { "timezone.excity.Europe/Zaporozhye", "Zaporizzsja" },
             { "timezone.excity.Pacific/Enderbury", "Enderbury" },
             { "timezone.excity.Pacific/Galapagos", "Galapagos-szigetek" },
             { "timezone.excity.Pacific/Kwajalein", "Kwajalein-z\u00e1tony" },
@@ -1890,7 +2070,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.America/Mexico_City", "Mexik\u00f3v\u00e1ros" },
             { "timezone.excity.Atlantic/Cape_Verde", "Z\u00f6ld-foki szigetek" },
             { "timezone.excity.Africa/Dar_es_Salaam", "Dar es-Salaam" },
-            { "timezone.excity.America/Santa_Isabel", "Santa Isabel" },
             { "timezone.excity.America/St_Barthelemy", "Saint-Barth\u00e9lemy" },
             { "timezone.excity.America/Bahia_Banderas", "Bahia Banderas" },
             { "timezone.excity.Atlantic/South_Georgia", "D\u00e9li-Georgia" },
