@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -86,9 +86,9 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
                "Temp da standard atlantic",
                "AST",
                "Temp da stad atlantic",
-               "ADT",
+               "AST",
                "Temp atlantic",
-               "AT",
+               "AST",
             };
         final String[] Europe_Central = new String[] {
                "Temp da standard da l\u2019Europa Centrala",
@@ -108,11 +108,11 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             };
         final String[] Europe_Western = new String[] {
                "Temp da standard da l\u2019Europa dal Vest",
-               "FMT",
+               "WET",
                "Temp da stad da l\u2019Europa dal Vest",
-               "FMT",
+               "WEST",
                "Temp da l\u2019Europa dal Vest",
-               "FMT",
+               "WET",
             };
         final String[] America_Central = new String[] {
                "Temp da standard central",
@@ -142,9 +142,9 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
                "Temp da standard da muntogna",
                "MST",
                "Temp da stad da muntogna",
-               "MDT",
+               "MST",
                "Temp da muntogna",
-               "MT",
+               "MST",
             };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
@@ -158,26 +158,123 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "GMT", GMT },
             { "Europe/Bucharest", Europe_Eastern },
             { "UTC", ETC_UTC },
+            { "GB",
+                new String[] {
+                    "Temp Greenwich",
+                    "GMT",
+                    "temp da stad britannic",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "ART", Europe_Eastern },
+            { "CET", Europe_Central },
             { "CST", America_Central },
             { "ECT", Europe_Central },
+            { "EET", Europe_Eastern },
+            { "EST", America_Eastern },
+            { "IET", America_Eastern },
+            { "MET", Europe_Central },
+            { "MST", America_Mountain },
             { "PNT", America_Mountain },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "UCT",
+                new String[] {
+                    "Temp universal coordin\u00e0",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "WET", Europe_Western },
+            { "Eire", GMT },
+            { "GMT0", GMT },
+            { "Zulu",
+                new String[] {
+                    "Temp universal coordin\u00e0",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Libya", Europe_Eastern },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "Temp universal coordin\u00e0",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Etc/UTC", ETC_UTC },
+            { "GB-Eire",
+                new String[] {
+                    "Temp Greenwich",
+                    "GMT",
+                    "temp da stad britannic",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "Temp universal coordin\u00e0",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Portugal", Europe_Western },
             { "Asia/Gaza", Europe_Eastern },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Universal",
+                new String[] {
+                    "Temp universal coordin\u00e0",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -197,10 +294,30 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "America/Aruba", Atlantic },
             { "America/Boise", America_Mountain },
             { "America/Thule", Atlantic },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "Temp universal coordin\u00e0",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin", GMT },
-            { "Europe/Jersey", GMT },
+            { "Europe/Jersey",
+                new String[] {
+                    "Temp Greenwich",
+                    "GMT",
+                    "temp da stad britannic",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -233,6 +350,11 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "America/Nassau", America_Eastern },
             { "America/Panama", America_Eastern },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -244,9 +366,11 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
+            { "Mexico/General", America_Central },
             { "Africa/Freetown", GMT },
             { "Africa/Monrovia", GMT },
             { "Africa/Sao_Tome", GMT },
@@ -258,6 +382,7 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Moncton", Atlantic },
@@ -268,14 +393,26 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "America/Tortola", Atlantic },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/Guernsey", GMT },
+            { "Europe/Guernsey",
+                new String[] {
+                    "Temp Greenwich",
+                    "GMT",
+                    "temp da stad britannic",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
@@ -283,9 +420,11 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "SystemV/MST7MDT", America_Mountain },
             { "SystemV/PST8PDT", America_Pacific },
             { "America/Anguilla", Atlantic },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Ensenada", America_Pacific },
             { "America/Montreal", America_Eastern },
             { "America/Resolute", America_Central },
             { "America/Shiprock", America_Mountain },
@@ -301,6 +440,7 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "Europe/Mariehamn", Europe_Eastern },
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Africa/Nouakchott", GMT },
             { "America/Chihuahua", America_Central },
             { "America/Glace_Bay", Atlantic },
@@ -316,6 +456,7 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "Europe/Luxembourg", Europe_Central },
             { "Europe/San_Marino", Europe_Central },
             { "Europe/Zaporozhye", Europe_Eastern },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Ouagadougou", GMT },
             { "America/Costa_Rica", America_Central },
             { "America/Grand_Turk", America_Eastern },
@@ -328,7 +469,16 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
-            { "Europe/Isle_of_Man", GMT },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "Temp Greenwich",
+                    "GMT",
+                    "temp da stad britannic",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "America/El_Salvador", America_Central },
             { "America/Fort_Nelson", America_Mountain },
@@ -340,11 +490,13 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "America/Thunder_Bay", America_Eastern },
             { "America/Yellowknife", America_Mountain },
             { "Arctic/Longyearbyen", Europe_Central },
+            { "Canada/Saskatchewan", America_Central },
             { "America/Blanc-Sablon", Atlantic },
             { "America/Danmarkshavn", GMT },
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
+            { "America/Santa_Isabel", America_Pacific },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -363,6 +515,7 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "America/Indiana/Petersburg", America_Eastern },
             { "timezone.excity.Asia/Seoul", "Seul" },
             { "timezone.excity.Asia/Tokyo", "Tokio" },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
@@ -376,6 +529,7 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Urumqi", "\u00dcr\u00fcmqi" },
             { "timezone.excity.Etc/Unknown", "citad nunenconuschenta" },
             { "timezone.excity.Europe/Rome", "Roma" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
             { "timezone.excity.Asia/Bishkek", "Bischkek" },
             { "timezone.excity.Asia/Karachi", "Karatschi" },
@@ -426,15 +580,12 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "timezone.excity.America/Cordoba", "C\u00f3rdoba" },
             { "timezone.excity.America/Godthab", "Godth\u00e5b" },
             { "timezone.excity.America/Jamaica", "Giamaica" },
-            { "timezone.excity.America/Noronha", "Fernando de Noronha" },
             { "timezone.excity.America/Tortola", "Road Town" },
-            { "timezone.excity.Asia/Choibalsan", "Tschoibalsan" },
             { "timezone.excity.Atlantic/Azores", "Azoras" },
             { "timezone.excity.Atlantic/Canary", "Inslas Canarias" },
             { "timezone.excity.Atlantic/Faeroe", "Inslas Feroe" },
             { "timezone.excity.Europe/Brussels", "Bruxelles" },
             { "timezone.excity.Europe/Guernsey", "Saint Peter Port" },
-            { "timezone.excity.Europe/Uzhgorod", "Uschhorod" },
             { "timezone.excity.Indian/Maldives", "Maldivas" },
             { "timezone.excity.Pacific/Gambier", "Rikitea" },
             { "timezone.excity.Pacific/Norfolk", "Kingston" },
@@ -458,7 +609,6 @@ public class TimeZoneNames_rm extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
             { "timezone.excity.America/St_Thomas", "Saint Thomas" },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
-            { "timezone.excity.Europe/Zaporozhye", "Saporischja" },
             { "timezone.excity.Pacific/Galapagos", "Gal\u00e1pagos" },
             { "timezone.excity.Pacific/Tongatapu", "Nuku\u02bbalofa" },
             { "timezone.excity.Africa/Addis_Ababa", "Addis Abeba" },
