@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -178,14 +178,6 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Casey = new String[] {
-               "\u010das Caseyho stanice",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Chile = new String[] {
                "\u010dilsk\u00fd \u0161tandardn\u00fd \u010das",
                "",
@@ -220,11 +212,11 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             };
         final String[] India = new String[] {
                "indick\u00fd \u010das",
+               "IST",
                "",
+               "IST",
                "",
-               "",
-               "",
-               "",
+               "IST",
             };
         final String[] Japan = new String[] {
                "japonsk\u00fd \u0161tandardn\u00fd \u010das",
@@ -300,11 +292,11 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "alja\u0161sk\u00fd \u0161tandardn\u00fd \u010das",
-               "",
+               "AKST",
                "alja\u0161sk\u00fd letn\u00fd \u010das",
-               "",
+               "AKDT",
                "alja\u0161sk\u00fd \u010das",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "amazonsk\u00fd \u0161tandardn\u00fd \u010das",
@@ -324,11 +316,11 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "azorsk\u00fd \u0161tandardn\u00fd \u010das",
-               "HMT",
+               "",
                "azorsk\u00fd letn\u00fd \u010das",
-               "HMT",
+               "",
                "azorsk\u00fd \u010das",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "bhut\u00e1nsky \u010das",
@@ -614,9 +606,9 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
                "atlantick\u00fd \u0161tandardn\u00fd \u010das",
                "AST",
                "atlantick\u00fd letn\u00fd \u010das",
-               "ADT",
+               "AST",
                "atlantick\u00fd \u010das",
-               "AT",
+               "AST",
             };
         final String[] Brasilia = new String[] {
                "braz\u00edlsky \u0161tandardn\u00fd \u010das",
@@ -850,6 +842,14 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Kazakhstan = new String[] {
+               "kazachstansk\u00fd \u010das",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Seychelles = new String[] {
                "seychelsk\u00fd \u010das",
                "",
@@ -988,11 +988,11 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "stredoafrick\u00fd \u010das",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "v\u00fdchodoafrick\u00fd \u010das",
@@ -1036,11 +1036,11 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             };
         final String[] Europe_Western = new String[] {
                "z\u00e1padoeur\u00f3psky \u0161tandardn\u00fd \u010das",
-               "FMT",
+               "WET",
                "z\u00e1padoeur\u00f3psky letn\u00fd \u010das",
-               "FMT",
+               "WEST",
                "z\u00e1padoeur\u00f3psky \u010das",
-               "FMT",
+               "WET",
             };
         final String[] Mexico_Pacific = new String[] {
                "mexick\u00fd tichomorsk\u00fd \u0161tandardn\u00fd \u010das",
@@ -1126,9 +1126,9 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
                "severoamerick\u00fd horsk\u00fd \u0161tandardn\u00fd \u010das",
                "MST",
                "severoamerick\u00fd horsk\u00fd letn\u00fd \u010das",
-               "MDT",
+               "MST",
                "severoamerick\u00fd horsk\u00fd \u010das",
-               "MT",
+               "MST",
             };
         final String[] Marshall_Islands = new String[] {
                "\u010das Marshallov\u00fdch ostrovov",
@@ -1138,14 +1138,6 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "severoz\u00e1padn\u00fd mexick\u00fd \u0161tandardn\u00fd \u010das",
-               "",
-               "severoz\u00e1padn\u00fd mexick\u00fd letn\u00fd \u010das",
-               "",
-               "severoz\u00e1padn\u00fd mexick\u00fd \u010das",
-               "",
-            };
         final String[] Papua_New_Guinea = new String[] {
                "\u010das Papuy-Novej Guiney",
                "",
@@ -1172,27 +1164,11 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             };
         final String[] Australia_Western = new String[] {
                "z\u00e1padoaustr\u00e1lsky \u0161tandardn\u00fd \u010das",
-               "",
+               "AWST",
                "z\u00e1padoaustr\u00e1lsky letn\u00fd \u010das",
-               "",
+               "AWDT",
                "z\u00e1padoaustr\u00e1lsky \u010das",
-               "",
-            };
-        final String[] Greenland_Eastern = new String[] {
-               "v\u00fdchodogr\u00f3nsky \u0161tandardn\u00fd \u010das",
-               "",
-               "v\u00fdchodogr\u00f3nsky letn\u00fd \u010das",
-               "",
-               "v\u00fdchodogr\u00f3nsky \u010das",
-               "",
-            };
-        final String[] Greenland_Western = new String[] {
-               "z\u00e1padogr\u00f3nsky \u0161tandardn\u00fd \u010das",
-               "",
-               "z\u00e1padogr\u00f3nsky letn\u00fd \u010das",
-               "",
-               "z\u00e1padogr\u00f3nsky \u010das",
-               "",
+               "AWT",
             };
         final String[] Indonesia_Central = new String[] {
                "stredoindon\u00e9zsky \u010das",
@@ -1218,22 +1194,6 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
                "",
                "WIB",
             };
-        final String[] Kazakhstan_Eastern = new String[] {
-               "v\u00fdchodokazachstansk\u00fd \u010das",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Kazakhstan_Western = new String[] {
-               "z\u00e1padokazachstansk\u00fd \u010das",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Australia_CentralWestern = new String[] {
                "stredoz\u00e1padn\u00fd austr\u00e1lsky \u0161tandardn\u00fd \u010das",
                "",
@@ -1270,54 +1230,196 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
             { "UTC", ETC_UTC },
+            { "GB",
+                new String[] {
+                    "greenwichsk\u00fd \u010das",
+                    "GMT",
+                    "britsk\u00fd letn\u00fd \u010das",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "NZ", New_Zealand },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "BET", Brasilia },
             { "BST", Bangladesh },
             { "CAT", Africa_Central },
+            { "CET", Europe_Central },
             { "CNT", Newfoundland },
             { "CST", America_Central },
             { "CTT", China },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "EET", Europe_Eastern },
+            { "EST", America_Eastern },
+            { "HST",
+                new String[] {
+                    "havajsko-aleutsk\u00fd \u0161tandardn\u00fd \u010das",
+                    "HST",
+                    "havajsko-aleutsk\u00fd letn\u00fd \u010das",
+                    "HDT",
+                    "havajsko-aleutsk\u00fd \u010das",
+                    "HST",
+                }
+            },
+            { "IET", America_Eastern },
+            { "IST", India },
             { "JST", Japan },
+            { "MET", Europe_Central },
             { "MIT", Apia },
+            { "MST", America_Mountain },
             { "NET", Armenia },
             { "NST", New_Zealand },
             { "PLT", Pakistan },
             { "PNT", America_Mountain },
+            { "PRC", China },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "ROK", Korea },
             { "SST", Solomon },
+            { "UCT",
+                new String[] {
+                    "koordinovan\u00fd svetov\u00fd \u010das",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "VST", Indochina },
+            { "WET", Europe_Western },
+            { "Cuba", Cuba },
+            { "Eire",
+                new String[] {
+                    "greenwichsk\u00fd \u010das",
+                    "GMT",
+                    "\u00edrsky \u0161tandardn\u00fd \u010das",
+                    "IST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "GMT0", GMT },
+            { "Iran", Iran },
+            { "W-SU", Moscow },
+            { "Zulu",
+                new String[] {
+                    "koordinovan\u00fd svetov\u00fd \u010das",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Japan", Japan },
+            { "Libya", Europe_Eastern },
+            { "Israel", Israel },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "koordinovan\u00fd svetov\u00fd \u010das",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Etc/UTC", ETC_UTC },
+            { "GB-Eire",
+                new String[] {
+                    "greenwichsk\u00fd \u010das",
+                    "GMT",
+                    "britsk\u00fd letn\u00fd \u010das",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
+            { "NZ-CHAT", Chatham },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "koordinovan\u00fd svetov\u00fd \u010das",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Hongkong", Hong_Kong },
+            { "Portugal", Europe_Western },
+            { "US/Samoa", Samoa },
             { "Asia/Aden", Arabian },
             { "Asia/Baku", Azerbaijan },
             { "Asia/Dili", East_Timor },
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
-            { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Aqtau", Kazakhstan_Western },
+            { "Asia/Oral", Kazakhstan },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Kwajalein", Marshall_Islands },
+            { "Singapore", Singapore },
+            { "US/Alaska", Alaska },
+            { "US/Hawaii",
+                new String[] {
+                    "havajsko-aleutsk\u00fd \u0161tandardn\u00fd \u010das",
+                    "HST",
+                    "havajsko-aleutsk\u00fd letn\u00fd \u010das",
+                    "HDT",
+                    "havajsko-aleutsk\u00fd \u010das",
+                    "HST",
+                }
+            },
+            { "Universal",
+                new String[] {
+                    "koordinovan\u00fd svetov\u00fd \u010das",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Asia/Aqtau", Kazakhstan },
             { "Asia/Chita", Yakutsk },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Dubai", Gulf },
             { "Asia/Kabul", Afghanistan },
+            { "Asia/Macao", China },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
-            { "Asia/Almaty", Kazakhstan_Eastern },
+            { "Asia/Almaty", Kazakhstan },
             { "Asia/Anadyr", Anadyr },
-            { "Asia/Aqtobe", Kazakhstan_Western },
-            { "Asia/Atyrau", Kazakhstan_Western },
+            { "Asia/Aqtobe", Kazakhstan },
+            { "Asia/Atyrau", Kazakhstan },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Brunei", Brunei },
             { "Asia/Harbin", China },
@@ -1329,12 +1431,21 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Asia/Saigon", Indochina },
             { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
+            { "Asia/Thimbu", Bhutan },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/Acre", Acre },
+            { "Brazil/East", Brasilia },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Indian/Mahe", Seychelles },
-            { "Pacific/Yap", Truk },
+            { "Pacific/Yap", Papua_New_Guinea },
+            { "US/Aleutian", Hawaii_Aleutian },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -1342,6 +1453,7 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
             { "America/Adak", Hawaii_Aleutian },
+            { "America/Atka", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
             { "Asia/Baghdad", Arabian },
@@ -1352,7 +1464,8 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Asia/Irkutsk", Irkutsk },
             { "Asia/Jakarta", Indonesia_Western },
             { "Asia/Karachi", Pakistan },
-            { "Asia/Kuching", Malaysia },
+            { "Asia/Kolkata", India },
+            { "Asia/Kuching", Brunei },
             { "Asia/Magadan", Magadan },
             { "Asia/Nicosia", Europe_Eastern },
             { "Asia/Rangoon", Myanmar },
@@ -1360,6 +1473,7 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Asia/Thimphu", Bhutan },
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
+            { "Canada/Yukon", Yukon },
             { "Europe/Malta", Europe_Central },
             { "Europe/Minsk", Moscow },
             { "Europe/Sofia", Europe_Eastern },
@@ -1377,6 +1491,7 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "SystemV/MST7", America_Mountain },
             { "SystemV/PST8", Pitcairn },
             { "SystemV/YST9", Gambier },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bamako", GMT },
             { "Africa/Bangui", Africa_Western },
@@ -1404,10 +1519,25 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
+            { "Asia/Qostanay", Kazakhstan },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
+            { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/LHI", Lord_Howe },
+            { "Australia/NSW", Australia_Eastern },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "koordinovan\u00fd svetov\u00fd \u010das",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
@@ -1420,7 +1550,16 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
-            { "Europe/Jersey", GMT },
+            { "Europe/Jersey",
+                new String[] {
+                    "greenwichsk\u00fd \u010das",
+                    "GMT",
+                    "britsk\u00fd letn\u00fd \u010das",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -1445,9 +1584,11 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Indian/Chagos", Indian_Ocean },
             { "Indian/Comoro", Africa_Eastern },
+            { "Pacific/Chuuk", Papua_New_Guinea },
             { "Pacific/Efate", Vanuatu },
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
+            { "Pacific/Samoa", Samoa },
             { "SystemV/HST10",
                 new String[] {
                     "havajsko-aleutsk\u00fd \u0161tandardn\u00fd \u010das",
@@ -1483,15 +1624,24 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
+            { "Asia/Chungking", China },
             { "Asia/Hong_Kong", Hong_Kong },
             { "Asia/Kamchatka", Kamchatka },
+            { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
             { "Asia/Pyongyang", Korea },
-            { "Asia/Qyzylorda", Kazakhstan_Western },
+            { "Asia/Qyzylorda", Kazakhstan },
             { "Asia/Samarkand", Uzbekistan },
             { "Asia/Singapore", Singapore },
             { "Asia/Vientiane", Indochina },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -1503,21 +1653,25 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "Indian/Reunion", Reunion },
+            { "Mexico/BajaSur", Mexico_Pacific },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kanton", Phoenix_Islands },
             { "Pacific/Kosrae", Kosrae },
             { "Pacific/Majuro", Marshall_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
-            { "Pacific/Ponape", Ponape },
+            { "Pacific/Ponape", Solomon },
             { "Pacific/Saipan", Chamorro },
             { "Pacific/Tahiti", Tahiti },
-            { "Pacific/Tarawa", Gilbert_Islands },
-            { "Pacific/Wallis", Wallis },
+            { "Pacific/Tarawa", Marshall_Islands },
+            { "Pacific/Wallis", Gilbert_Islands },
             { "Africa/Blantyre", Africa_Central },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Freetown", GMT },
@@ -1536,10 +1690,10 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Godthab", Greenland_Western },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
@@ -1553,25 +1707,41 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "America/Yakutat", Alaska },
             { "Asia/Choibalsan", Mongolia },
             { "Asia/Phnom_Penh", Indochina },
+            { "Asia/Ulan_Bator", Mongolia },
             { "Atlantic/Azores", Azores },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/North", Australia_Central },
             { "Australia/Perth", Australia_Western },
+            { "Australia/South", Australia_Central },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/Guernsey", GMT },
+            { "Europe/Guernsey",
+                new String[] {
+                    "greenwichsk\u00fd \u010das",
+                    "GMT",
+                    "britsk\u00fd letn\u00fd \u010das",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
-            { "Indian/Maldives", Maldives },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
             { "Pacific/Fakaofo", Tokelau },
             { "Pacific/Gambier", Gambier },
             { "Pacific/Norfolk", Norfolk },
+            { "Pacific/Pohnpei", Solomon },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
@@ -1582,10 +1752,12 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Africa/Mogadishu", Africa_Eastern },
             { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
             { "America/Eirunepe", Acre },
+            { "America/Ensenada", America_Pacific },
             { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
@@ -1596,10 +1768,11 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
+            { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1611,6 +1784,7 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
@@ -1621,9 +1795,19 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
-            { "Pacific/Johnston", Hawaii_Aleutian },
+            { "Pacific/Johnston",
+                new String[] {
+                    "havajsko-aleutsk\u00fd \u0161tandardn\u00fd \u010das",
+                    "HST",
+                    "havajsko-aleutsk\u00fd letn\u00fd \u010das",
+                    "HDT",
+                    "havajsko-aleutsk\u00fd \u010das",
+                    "HST",
+                }
+            },
             { "Pacific/Pitcairn", Pitcairn },
             { "Africa/Libreville", Africa_Western },
             { "Africa/Lubumbashi", Africa_Central },
@@ -1648,6 +1832,7 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Antarctica/Vostok", Vostok },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Chile/Continental", Chile },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
             { "Europe/Luxembourg", Europe_Central },
@@ -1661,6 +1846,7 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Pacific/Pago_Pago", Samoa },
             { "Pacific/Rarotonga", Cook },
             { "Pacific/Tongatapu", Tonga },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "Africa/Ouagadougou", GMT },
@@ -1675,19 +1861,34 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "America/Montevideo", Uruguay },
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
+            { "America/Porto_Acre", Acre },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
             { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
             { "Australia/Adelaide", Australia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
-            { "Europe/Isle_of_Man", GMT },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "greenwichsk\u00fd \u010das",
+                    "GMT",
+                    "britsk\u00fd letn\u00fd \u010das",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "Pacific/Kiritimati", Line_Islands },
             { "Africa/Johannesburg", Africa_Southern },
@@ -1705,6 +1906,8 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Pacific/Guadalcanal", Solomon },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
@@ -1715,10 +1918,11 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Santa_Isabel", Mexico_Northwest },
-            { "America/Scoresbysund", Greenland_Eastern },
+            { "America/Santa_Isabel", America_Pacific },
             { "Antarctica/Macquarie", Australia_Eastern },
-            { "Pacific/Port_Moresby", Papua_New_Guinea },
+            { "Australia/Queensland", Australia_Eastern },
+            { "Australia/Yancowinna", Australia_Central },
+            { "Pacific/Port_Moresby", DumontDUrville },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1733,9 +1937,12 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
             { "Atlantic/South_Georgia", South_Georgia },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -1756,10 +1963,13 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Qatar", "Katar" },
             { "timezone.excity.Asia/Seoul", "Soul" },
             { "timezone.excity.Asia/Tokyo", "Tokio" },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Africa/Lome", "Lom\u00e9" },
+            { "timezone.excity.Asia/Almaty", "Alma\u2011Ata" },
             { "timezone.excity.Asia/Aqtobe", "Aktobe" },
             { "timezone.excity.Asia/Beirut", "Bejr\u00fat" },
             { "timezone.excity.Asia/Brunei", "Brunej" },
@@ -1774,6 +1984,8 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Kiev", "Kyjev" },
             { "timezone.excity.Europe/Rome", "R\u00edm" },
             { "timezone.excity.Indian/Mahe", "Mah\u00e9" },
+            { "America/Indiana/Indianapolis", America_Eastern },
+            { "timezone.excity.Africa/Accra", "Akkra" },
             { "timezone.excity.Africa/Cairo", "K\u00e1hira" },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
             { "timezone.excity.Asia/Bahrain", "Bahrajn" },
@@ -1813,9 +2025,11 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Zagreb", "Z\u00e1hreb" },
             { "timezone.excity.Europe/Zurich", "Z\u00fcrich" },
             { "timezone.excity.Indian/Comoro", "Komory" },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Algiers", "Al\u017e\u00edr" },
+            { "timezone.excity.Africa/Conakry", "Konakry" },
             { "timezone.excity.Africa/Tripoli", "Tripolis" },
             { "timezone.excity.America/Bogota", "Bogot\u00e1" },
             { "timezone.excity.America/Cayman", "Kajmanie ostrovy" },
@@ -1838,7 +2052,6 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Sao_Tome", "Sv\u00e4t\u00fd Tom\u00e1\u0161" },
             { "timezone.excity.America/Cordoba", "C\u00f3rdoba" },
             { "timezone.excity.America/Jamaica", "Jamajka" },
-            { "timezone.excity.Asia/Choibalsan", "\u010cojbalsan" },
             { "timezone.excity.Asia/Phnom_Penh", "Phnom P\u00e9nh" },
             { "timezone.excity.Atlantic/Azores", "Azory" },
             { "timezone.excity.Atlantic/Canary", "Kan\u00e1rske ostrovy" },
@@ -1848,7 +2061,6 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Budapest", "Budape\u0161\u0165" },
             { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
             { "timezone.excity.Europe/Chisinau", "Ki\u0161i\u0148ov" },
-            { "timezone.excity.Europe/Uzhgorod", "U\u017ehorod" },
             { "timezone.excity.Indian/Maldives", "Maldivy" },
             { "timezone.excity.Africa/Mogadishu", "Mogadi\u0161o" },
             { "timezone.excity.America/Dominica", "Dominika" },
@@ -1860,7 +2072,6 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Krasnoyarsk", "Krasnojarsk" },
             { "timezone.excity.Asia/Ulaanbaatar", "Ulanb\u00e1tar" },
             { "timezone.excity.Atlantic/Bermuda", "Bermudy" },
-            { "timezone.excity.Australia/Currie", "Currie" },
             { "timezone.excity.Europe/Astrakhan", "Astrach\u00e1n" },
             { "timezone.excity.Europe/Bucharest", "Bukure\u0161\u0165" },
             { "timezone.excity.Europe/Gibraltar", "Gibralt\u00e1r" },
@@ -1877,7 +2088,6 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Copenhagen", "Koda\u0148" },
             { "timezone.excity.Europe/Luxembourg", "Luxembursko" },
             { "timezone.excity.Europe/San_Marino", "San Mar\u00edno" },
-            { "timezone.excity.Europe/Zaporozhye", "Z\u00e1poro\u017eie" },
             { "timezone.excity.Pacific/Enderbury", "Enderbury" },
             { "timezone.excity.Pacific/Galapagos", "Galap\u00e1gy" },
             { "timezone.excity.Pacific/Marquesas", "Mark\u00e9zy" },
@@ -1893,7 +2103,6 @@ public class TimeZoneNames_sk extends TimeZoneNamesBundle {
             { "timezone.excity.America/Mexico_City", "M\u00e9xico" },
             { "timezone.excity.America/Puerto_Rico", "Portoriko" },
             { "timezone.excity.Atlantic/Cape_Verde", "Kapverdy" },
-            { "timezone.excity.America/Santa_Isabel", "Santa Isabel" },
             { "timezone.excity.America/St_Barthelemy", "Sv\u00e4t\u00fd Bartolomej" },
             { "timezone.excity.America/Bahia_Banderas", "Bahia Banderas" },
             { "timezone.excity.Atlantic/South_Georgia", "Ju\u017en\u00e1 Georgia" },
